package com.mpaas.demo.analytics.testcase;

import com.alipay.mobile.common.logging.api.LoggerFactory;
import com.alipay.mobile.common.logging.strategy.LogStrategyInfo;
import com.mpaas.diagnose.CaseInfo;
import com.mpaas.diagnose.ICase;

import java.util.Map;

/**
 * Created by xingcheng on 2019/2/26.
 */

public class LogStrategyCase extends BaseCase {

    private static LogStrategyCase sInstance;
    private CaseInfo mCaseInfo;

    private LogStrategyCase() {
    }

    public static LogStrategyCase getInstance() {
        if (sInstance == null) {
            synchronized (LogStrategyCase.class) {
                if (sInstance == null) {
                    sInstance = new LogStrategyCase();
                }
            }
        }
        return sInstance;
    }

    @Override
    public CaseInfo getCaseInfo() {
        if (mCaseInfo == null) {
            mCaseInfo = new CaseInfo(
                    "Analytics",
                    "Analytics-000001",
                    "检测日志上报策略",
                    "自动输出日志上报策略",
                    false
            );
        }
        return mCaseInfo;
    }

    @Override
    public void run() {
        Map<String, LogStrategyInfo> logStrategyInfos = LoggerFactory.getLogContext().getLogStrategyInfos();
        StringBuilder sb = new StringBuilder();
        for (Map.Entry<String, LogStrategyInfo> entry : logStrategyInfos.entrySet()) {
            LogStrategyInfo info = entry.getValue();
            sb
                    .append("\n")
                    .append("业务码：").append(entry.getKey()).append("\n")
                    .append("开关：").append(info.isWrite()).append("\n")
                    .append("上报条数：").append(info.getThreshold()).append("\n")
                    .append("上报率：").append(info.getUploadRate()).append("\n")
                    .append("上报等级：").append(info.getLevel()).append("\n");

            if (info.isHasSendCondition()) {
                sb.append("网络：[");
                for (String condition : info.getSendCondition()) {
                    sb.append(condition).append(", ");
                }
                sb.replace(sb.length() - 2, sb.length() - 1, "]").append("\n");
            }

            if (info.getUploadEvents().size() > 0) {
                sb.append("策略：[");
                for (String event : info.getUploadEvents()) {
                    sb.append(event).append(", ");
                }
                sb.replace(sb.length() - 2, sb.length() - 1, "]").append("\n");
            }
        }
        reportSuccess(sb.toString());
    }


}
