package com.mpaas.demo.analytics.testcase.listener;

import com.alipay.mobile.common.logging.api.LogEvent;
import com.alipay.mobile.common.logging.api.ProcessInfo;
import com.mpaas.demo.analytics.testcase.AnalyticsDiagnoseController;
import com.mpaas.demo.analytics.testcase.UploadCase;
import com.mpaas.diagnose.CaseInfo;
import com.mpaas.diagnose.ILogListener;

import java.util.ArrayList;
import java.util.HashSet;
import java.util.List;
import java.util.Set;

/**
 * Created by xingcheng on 2019/2/28.
 */

public class UploadListener implements ILogListener {

    private Set<String> uploadSuccess = new HashSet<>();
    private Set<String> uploadFailed = new HashSet<>();
    private Set<String> uploadSkipped = new HashSet<>();

    @Override
    public String getTag() {
        return "MdapLogUploadManager";
    }

    @Override
    public List<String> getProcesses() {
        List<String> processes = new ArrayList<>();
        processes.add(ProcessInfo.ALIAS_TOOLS);
        return processes;
    }

    @Override
    public boolean canFuzzyMatch() {
        return false;
    }

    @Override
    public void onLogAppend(LogEvent logEvent, String process) {
        int levelInt = logEvent.getLevel().levelInt;
        String msg = logEvent.getMessage();

        if (levelInt == LogEvent.Level.INFO_INT) {
            if (msg.contains("upload success")) {
                uploadSuccess.add(msg);
            } else if (msg.contains("uploadLog end")) {
                AnalyticsDiagnoseController.service.reportCase(
                        UploadCase.getInstance().getCaseInfo(),
                        CaseInfo.RESULT_CODE_SUCCESS,
                        getUploadResult()
                );
            }

        } else if (levelInt == LogEvent.Level.WARN_INT) {
            if (msg.endsWith("limited and not performed")) {
                uploadSkipped.add(msg);
            } else if (msg.contains("all the uploading are failed")) {
                AnalyticsDiagnoseController.service.reportCase(
                        UploadCase.getInstance().getCaseInfo(),
                        CaseInfo.RESULT_CODE_FAIL,
                        getUploadResult()
                );
            }

        } else if (levelInt == LogEvent.Level.ERROR_INT) {
            if (msg.contains("upload failed")) {
                uploadFailed.add(msg);
            }
        }
    }

    private String getUploadResult() {
        StringBuilder sb = new StringBuilder();
        if (uploadSuccess.size() > 0) {
            sb.append("上传成功：\n");
            for (String s : uploadSuccess) {
                sb.append(s).append("\n");
            }
        }
        if (uploadFailed.size() > 0) {
            sb.append("上传失败：\n");
            for (String s : uploadFailed) {
                sb.append(s).append("\n");
            }
        }
        if (uploadSkipped.size() > 0) {
            sb.append("上传跳过：\n");
            for (String s : uploadSkipped) {
                sb.append(s).append("\n");
            }
        }
        return sb.toString();
    }
}
