package com.mpaas.demo.analytics.testcase.util;

import android.app.Application;
import android.support.annotation.NonNull;
import android.text.TextUtils;
import android.util.SparseArray;

import com.alipay.mobile.common.logging.api.LoggerFactory;
import com.alipay.mobile.framework.LauncherApplicationAgent;
import com.mpaas.mas.adapter.api.MPLogger;

import java.io.File;
import java.io.FileInputStream;
import java.util.ArrayList;
import java.util.List;

/**
 * Created by xingcheng on 2019/2/26.
 */

public class LogFileUtil {

    private static final String MDAP_FILE_DIR = "mdap";
    private static final String UPLOAD_FILE_DIR = "upload";

    /**
     * 查找已写入文件的日志
     *
     * @param category    日志类别，与日志文件名有关
     * @param identifiers 辨识日志的字段，key为字段位置，value为字段值
     * @return 找到的日志
     */
    public static List<String> findLogInFile(@NonNull String category, @NonNull SparseArray<String> identifiers) {
        List<File> logFiles = findLogFile(category);
        if (logFiles == null || logFiles.size() == 0) {
            return null;
        }
        List<String> logs = new ArrayList<>();
        for (File logFile : logFiles) {
            String content = LogFileUtil.readFile(logFile);
            if (TextUtils.isEmpty(content)) {
                continue;
            }
            String[] split = content.split("\\$\\$");
            int maxIdentifierPosition = identifiers.keyAt(identifiers.size() - 1);
            for (String log : split) {
                // 密文需先解密
                if (log.startsWith("1_")) {
                    log = LoggerFactory.getLogContext().getLogEncryptClient().decrypt(log.substring(2));
                }
                String[] fields = log.split(",");
                if (fields.length <= maxIdentifierPosition) {
                    continue;
                }
                boolean matched = true;
                for (int i = 0; i < identifiers.size(); i++) {
                    if (!TextUtils.equals(fields[identifiers.keyAt(i)], identifiers.valueAt(i))) {
                        matched = false;
                        break;
                    }
                }
                if (matched) {
                    logs.add(log);
                }
            }
        }
        return logs;
    }

    public static List<File> findLogFile(String category) {
        Application context = LauncherApplicationAgent.getInstance().getApplicationContext();
        boolean offlineMode = MPLogger.isOfflineMode();
        File logDir = offlineMode ?
                context.getExternalFilesDir(MDAP_FILE_DIR) :
                new File(context.getFilesDir(), MDAP_FILE_DIR);
        if (logDir == null || !logDir.exists()) {
            return null;
        }
        List<File> logFiles = new ArrayList<>();
        String fileName = LoggerFactory.getProcessInfo().getProcessTag() + "_" + category;
        File logFile = new File(logDir, fileName);
        if (logFile.exists()) {
            logFiles.add(logFile);
            return logFiles;
        }
        // 如果不存在，有可能是已经上报了，线下模式可在备份目录里找
        if (offlineMode) {
            logDir = context.getExternalFilesDir(MDAP_FILE_DIR + File.separator + UPLOAD_FILE_DIR);
            if (logDir == null || !logDir.exists()) {
                return null;
            }
            File[] uploadedFiles = logDir.listFiles();
            for (File file : uploadedFiles) {
                if (file.exists() && file.getName().endsWith(fileName)) {
                    logFiles.add(file);
                }
            }
        }
        return logFiles;
    }

    public static String readFile(File filePath) {
        FileInputStream in = null;
        try {
            in = new FileInputStream(filePath);
            //一次读完
            int size = in.available();
            byte[] buffer = new byte[size];
            in.read(buffer);
            String str = new String(buffer, "UTF-8");
            return str;
        } catch (Throwable e) {
            e.printStackTrace();
            return null;
        } finally {
            if (in != null) {
                try {
                    in.close();
                } catch (Throwable e) {//NOPMD
                }
            }
        }
    }

}
