package com.mpaas.demo.launcher;

import android.Manifest;
import android.content.SharedPreferences;
import android.content.pm.PackageManager;
import android.os.Bundle;
import android.os.Process;
import android.preference.PreferenceManager;
import android.support.v4.app.ActivityCompat;
import android.support.v4.app.Fragment;
import android.support.v4.app.FragmentTransaction;
import android.support.v4.content.ContextCompat;
import android.text.TextUtils;

import com.alipay.mobile.framework.app.ui.BaseFragmentActivity;
import com.mpaas.framework.adapter.api.MPFramework;
import com.mpaas.mas.adapter.api.MPLogger;
import com.ut.device.UTDevice;


/**
 * Created by ciwei on 18/6/17.
 */
public class MainActivity extends BaseFragmentActivity{

    protected static final int PERMISSION_REQUEST_CODE = 0X01;
    protected Fragment mMainFragment;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);
        checkPermission();
        initView();
        MPLogger.reportLaunchTime(this);
        // 这里先记录下userId，供其他bundle使用
        MPLogger.setUserId(User.getUserId(this));
        // UTDID 测试case
        utdIdTestCase();
    }

    private void utdIdTestCase() {
        SharedPreferences pref = PreferenceManager.getDefaultSharedPreferences(MPFramework.getApplicationContext());
        String lastProcessUtdid = pref.getString("mpaas_utdid", "");
        if (TextUtils.isEmpty(lastProcessUtdid)) {
            int pid = Process.myPid();
            pref.edit().putString("mpaas_utdid", pid + "_" + UTDevice.getUtdid(this)).apply();
        } else {
            String[] values = lastProcessUtdid.split("_");
            if (UTDevice.getUtdid(this).equals(values[1])) {
                MPLogger.debug("mpaas_demo_framework", "Utdid success");
            } else {
                MPLogger.debug("mpaas_demo_framework", "Utdid failed");
            }
        }
    }

    protected void checkPermission() {
        if (ContextCompat.checkSelfPermission(this, Manifest.permission.READ_EXTERNAL_STORAGE)
                != PackageManager.PERMISSION_GRANTED
                || ContextCompat.checkSelfPermission(this, Manifest.permission.WRITE_EXTERNAL_STORAGE)
                != PackageManager.PERMISSION_GRANTED) {
            ActivityCompat.requestPermissions(this,
                    new String[]{Manifest.permission.READ_EXTERNAL_STORAGE, Manifest.permission.WRITE_EXTERNAL_STORAGE},
                    PERMISSION_REQUEST_CODE);
        }
    }

    /**
     * 监控启动时间
     */
    protected void monitorLaunchTime() {
    }

    protected void initView() {
        mMainFragment = new MpaasDemoFragment();
        FragmentTransaction transaction = getSupportFragmentManager().beginTransaction();
        if (!mMainFragment.isAdded()) {
            transaction.add(R.id.main_container_fl, mMainFragment).commitAllowingStateLoss();
        } else {
            transaction.show(mMainFragment).commitAllowingStateLoss();
        }
    }

}
