package com.mpaas.demo.launcher;

import android.content.Intent;
import android.os.Bundle;
import android.support.annotation.Nullable;
import android.support.v4.app.Fragment;
import android.support.v4.content.LocalBroadcastManager;
import android.text.TextUtils;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.ExpandableListView;
import android.widget.Toast;

import com.alipay.mobile.antui.basic.AUToast;
import com.alipay.mobile.framework.MicroApplicationContext;
import com.alipay.mobile.framework.app.ActivityApplication;
import com.mpaas.demo.framework.api.Constants;
import com.mpaas.demo.framework.api.IDataService;
import com.mpaas.demo.launcher.expandview.ComponentGroupModel;
import com.mpaas.demo.launcher.expandview.ComponentModel;
import com.mpaas.demo.launcher.expandview.IComponentModel;
import com.mpaas.demo.launcher.expandview.MainExpandableListAdapter;
import com.mpaas.diagnose.DiagnoseService;
import com.mpaas.framework.adapter.api.MPFramework;
import com.mpaas.mas.adapter.api.MPLogger;

import java.util.ArrayList;
import java.util.List;

public class MpaasDemoFragment extends Fragment implements ExpandableListView.OnChildClickListener, ExpandableListView.OnGroupClickListener {

    protected ExpandableListView mMainElv;
    protected MainExpandableListAdapter mMainAdapter;
    protected View mRootView;

    @Nullable
    @Override
    public View onCreateView(LayoutInflater inflater, @Nullable ViewGroup container, Bundle savedInstanceState) {
        mRootView = inflater.inflate(R.layout.fragment_mpaas_demo, container, false);
        initView();
        return mRootView;
    }

    protected void initView() {
        mMainElv = (ExpandableListView) mRootView.findViewById(R.id.main_elv);
        mMainAdapter = new MainExpandableListAdapter(this.getActivity());
        mMainElv.setAdapter(mMainAdapter);
        mMainElv.setOnChildClickListener(this);
        mMainElv.setOnGroupClickListener(this);
        mMainAdapter.setComponentModel(initialData());
    }

    protected List<ComponentGroupModel> initialData() {
        List<ComponentGroupModel> componentGroupModels = new ArrayList<>();
        componentGroupModels.add(initFrameWork());
        componentGroupModels.add(initMaterialDesign());
        componentGroupModels.add(initMobileGateway());
        componentGroupModels.add(initMobileAnalytics());
        componentGroupModels.add(initRelease());
        componentGroupModels.add(initPush());
        componentGroupModels.add(initSync());
        componentGroupModels.add(initH5());
        componentGroupModels.add(initMiniApp());
        componentGroupModels.add(initAntUI());
        componentGroupModels.add(initShare());
        componentGroupModels.add(initScan());
        componentGroupModels.add(initStorage());
        componentGroupModels.add(initLbs());
        // debug 模式下，且加入了 diagnose-build bundle，才去开启 testcase 诊断功能
        if (MPLogger.isDebug(MPFramework.getApplicationContext())
                && null != MPFramework.getExternalService(DiagnoseService.class.getName())) {
            componentGroupModels.add(initDiagnose());
        }
        return componentGroupModels;
    }

    protected ComponentGroupModel initMobileGateway() {
        return new ComponentGroupModel(new ComponentModel(getString(R.string.mobile_gateway), getString(R.string.appid_rpc)), null);
    }

    protected ComponentGroupModel initMaterialDesign() {
        return new ComponentGroupModel(new ComponentModel(getString(R.string.material_design), getString(R.string.appid_material_design)), null);
    }

    protected ComponentGroupModel initMobileAnalytics() {
        return new ComponentGroupModel(new ComponentModel(getString(R.string.mobile_analytics), getString(R.string.appid_analytics)), null);
    }

    protected ComponentGroupModel initRelease() {
        List<ComponentModel> modelList = new ArrayList<>();
        modelList.add(new ComponentModel(getString(R.string.upgrade_release), getString(R.string.appid_upgrade)));
        modelList.add(new ComponentModel(getString(R.string.hotpatch_release), getString(R.string.appid_hotpatch)));
        modelList.add(new ComponentModel(getString(R.string.configservice), getString(R.string.appid_configservice)));
        return new ComponentGroupModel(new ComponentModel(getString(R.string.real_time_release)), modelList);
    }

    protected ComponentGroupModel initShare() {
        return new ComponentGroupModel(new ComponentModel(getString(R.string.share), getString(R.string.appid_share)), null);
    }

    protected ComponentGroupModel initStorage() {
        List<ComponentModel> modelList = new ArrayList<>();
        Bundle db = new Bundle();
        String appId = getString(R.string.appid_storage);
        db.putString("start", "DB");
        modelList.add(new ComponentModel(getString(R.string.db_storage), appId, db));
        Bundle kv = new Bundle();
        kv.putString("start", "KV");
        modelList.add(new ComponentModel(getString(R.string.kv_storage), appId, kv));
        Bundle file = new Bundle();
        file.putString("start", "File");
        modelList.add(new ComponentModel(getString(R.string.file_storage), appId, file));
        return new ComponentGroupModel(new ComponentModel(getString(R.string.storage)), modelList);
    }

    protected ComponentGroupModel initLbs() {
        return new ComponentGroupModel(new ComponentModel(getString(R.string.lbs), getString(R.string.appid_lbs)), null);
    }

    protected ComponentGroupModel initH5() {
        List<ComponentModel> modelList = new ArrayList<>();
        String targetAppId = getString(R.string.appid_nebula);
        Bundle params = new Bundle();
        params.putString("type", "online");
        modelList.add(new ComponentModel(getString(R.string.open_url), targetAppId, params));
        params = new Bundle();
        params.putString("type", "h5app");
        modelList.add(new ComponentModel(getString(R.string.open_h5_app), targetAppId, params));
        params = new Bundle();
        params.putString("type", "customize");
        modelList.add(new ComponentModel(getString(R.string.customize_nebula), targetAppId, params));
        params = new Bundle();
        params.putString("type", "others");
        modelList.add(new ComponentModel(getString(R.string.h5_other_function), targetAppId, params));
        return new ComponentGroupModel(new ComponentModel(getString(R.string.h5)), modelList);
    }

    protected ComponentGroupModel initMiniApp() {
        Bundle params = new Bundle();
        params.putString("type", "mini");

        return new ComponentGroupModel(new ComponentModel(getString(R.string.mini_app), getString(R.string.appid_nebula), params), null);
    }

    protected ComponentGroupModel initAntUI() {
        return new ComponentGroupModel(new ComponentModel(getString(R.string.antui), getString(R.string.appid_antui), null), null);
    }

    protected ComponentGroupModel initSync() {
        List<ComponentModel> modelList = new ArrayList<>();
        String targetAppId = getString(R.string.appid_sync);
        Bundle params = new Bundle();
        params.putString("type", "device");
        modelList.add(new ComponentModel(getString(R.string.sync_device), targetAppId, params));
        params = new Bundle();
        params.putString("type", "user");
        modelList.add(new ComponentModel(getString(R.string.sync_uid), targetAppId, params));
        return new ComponentGroupModel(new ComponentModel(getString(R.string.sync)), modelList);
    }

    protected ComponentGroupModel initPush() {
        return new ComponentGroupModel(new ComponentModel(getString(R.string.push), getString(R.string.appid_push)), null);
    }

    protected ComponentGroupModel initFrameWork() {
        List<ComponentModel> modelList = new ArrayList<>();
        Bundle params = new Bundle();
        params.putString(Constants.DEST_KEY, Constants.DEST_VALUE_ACTIVITY_APPLICATION_MAIN);
        modelList.add(new ComponentModel(getString(R.string.framework_activityapplication), getString(R.string.appid_framework_activityapplication), params));
        ComponentModel model = new ComponentModel(getString(R.string.framework_service), null);
        model.setModelHandler(new IComponentModel() {
            @Override
            public void handle() {
                IDataService dataService = MPFramework.getExternalService(IDataService.class.getName());
                AUToast.makeToast(getActivity(), com.alipay.mobile.antui.R.drawable.toast_ok, dataService.getData(), Toast.LENGTH_SHORT).show();
            }
        });
        modelList.add(model);
        model = new ComponentModel(getString(R.string.framework_boradcast), null);
        model.setModelHandler(new IComponentModel() {
            @Override
            public void handle() {
                LocalBroadcastManager.getInstance(MPFramework.getApplicationContext()).sendBroadcast(new Intent(Constants.ACTION_TEST));
            }
        });
        modelList.add(model);
        params = new Bundle();
        params.putString(Constants.DEST_KEY, Constants.DEST_VALUE_ACTIVITY_PIPELINE);
        model = new ComponentModel(getString(R.string.framework_pipeline), getString(R.string.appid_framework_activityapplication), params);
        modelList.add(model);
        return new ComponentGroupModel(new ComponentModel(getString(R.string.framework)), modelList);
    }

    protected ComponentGroupModel initScan() {
        return new ComponentGroupModel(new ComponentModel(getString(R.string.scan), getString(R.string.appid_scan)), null);
    }

    protected ComponentGroupModel initDiagnose() {
        return new ComponentGroupModel(new ComponentModel(getString(R.string.diagnose), getString(R.string.appid_diagnose)), null);
    }

    protected void handleClick(ComponentModel componentModel) {
        if (null != componentModel.mModelHandler) {
            componentModel.mModelHandler.handle();
            return;
        }
        if (TextUtils.isEmpty(componentModel.appId)) {
            AUToast.makeToast(getActivity(), 0, getString(R.string.coming_soon), Toast.LENGTH_SHORT).show();
            return;
        }

        MicroApplicationContext context = MPFramework.getMicroApplicationContext();
        String curId = "";
        ActivityApplication curApp = context.getTopApplication();
        if (null != curApp) {
            curId = curApp.getAppId();
        }
        context.startApp(curId, componentModel.appId, componentModel.bundle);
    }

    @Override
    public boolean onChildClick(ExpandableListView expandableListView, View view, int groupPosition, int childPosition, long l) {
        handleClick(mMainAdapter.getChild(groupPosition, childPosition));
        return false;
    }

    @Override
    public boolean onGroupClick(ExpandableListView parent, View v, int groupPosition, long id) {
        List<ComponentModel> children = mMainAdapter.getGroup(groupPosition);
        if (null == children || children.isEmpty()) {
            ComponentGroupModel groupModel = mMainAdapter.getGroupModel(groupPosition);
            if (null != groupModel && null != groupModel.titleModel) {
                handleClick(groupModel.titleModel);
            }
            return true;
        }
        return false;
    }
}
