package com.mpaas.demo.lbs.testcase;

import com.alipay.mobile.common.lbs.LBSLocation;
import com.alipay.mobile.common.lbs.LBSLocationListener;
import com.alipay.mobile.common.lbs.LBSLocationManagerProxy;
import com.alipay.mobile.framework.LauncherApplicationAgent;
import com.mpaas.diagnose.CaseInfo;
import com.mpaas.diagnose.ICase;

import java.util.concurrent.TimeUnit;

/**
 * Created by xingcheng on 2019/3/5.
 */

public class RequestLocationCase implements ICase, LBSLocationListener {

    private static RequestLocationCase sInstance;
    private CaseInfo mCaseInfo;

    private RequestLocationCase() {
    }

    public static RequestLocationCase getInstance() {
        if (sInstance == null) {
            synchronized (RequestLocationCase.class) {
                if (sInstance == null) {
                    sInstance = new RequestLocationCase();
                }
            }
        }
        return sInstance;
    }

    @Override
    public CaseInfo getCaseInfo() {
        if (mCaseInfo == null) {
            mCaseInfo = new CaseInfo(
                    "Lbs",
                    "Lbs-000001",
                    "检测定位接口",
                    "自动检测定位接口",
                    false
            );
        }
        return mCaseInfo;
    }

    @Override
    public void run() {
        LBSLocationManagerProxy.getInstance().doRequestLocationUpdates(
                // context上下文
                LauncherApplicationAgent.getInstance().getApplicationContext(),
                // 是否需要gps
                false,
                // 定位回调
                this,
                // 定位时间间隔
                TimeUnit.SECONDS.toMillis(30L),
                // 定位超时时间
                TimeUnit.SECONDS.toMillis(31L),
                // 是否需要逆地理
                true,
                // biz标识
                "testcase",
                // 是否需要速度
                false,
                // 是否是H5
                "F");
    }

    @Override
    public void onLocationUpdate(LBSLocation lbsLocation) {
        LbsDiagnoseController.service.reportCase(mCaseInfo, CaseInfo.RESULT_CODE_SUCCESS, getLocationString(lbsLocation));
    }

    private String getLocationString(LBSLocation location) {
        StringBuilder sb = new StringBuilder();
        // 获取经度
        sb.append("经度：");
        sb.append(location.getLongitude());
        sb.append("\n");
        // 获取纬度
        sb.append("纬度：");
        sb.append(location.getLatitude());
        sb.append("\n");
        // 获取城市编码
        sb.append("城市编码：");
        sb.append(location.getAdCode());
        sb.append("\n");
        // 获取国家
        sb.append("国家：");
        sb.append(location.getCountry());
        sb.append("\n");
        // 获取省
        sb.append("省：");
        sb.append(location.getProvince());
        sb.append("\n");
        // 获取市
        sb.append("市：");
        sb.append(location.getCity());
        sb.append("\n");
        // 获取区
        sb.append("区：");
        sb.append(location.getDistrict());
        sb.append("\n");
        // 获取街道
        sb.append("街道：");
        sb.append(location.getStreet());
        sb.append("\n");
        // 获取地址
        sb.append("地址：");
        sb.append(location.getAddress());
        return sb.toString();
    }

    @Override
    public void onLocationFailed(int i) {
        LbsDiagnoseController.service.reportCase(mCaseInfo, CaseInfo.RESULT_CODE_FAIL, "获取定位失败：" + i);
    }
}
