package com.mpaas.demo.nebula;

import android.os.Bundle;
import android.view.View;

import com.alipay.mobile.antui.basic.AUTitleBar;
import com.alipay.mobile.antui.basic.AUToast;
import com.alipay.mobile.framework.app.ui.BaseActivity;
import com.alipay.mobile.h5container.api.H5Plugin;
import com.alipay.mobile.nebula.provider.H5JSApiPermissionProvider;
import com.alipay.mobile.nebula.provider.H5ReplaceResourceProvider;
import com.alipay.mobile.nebula.util.H5Utils;
import com.mpaas.demo.sharedres.MenuPopupWindow;
import com.mpaas.nebula.adapter.api.MPNebula;

/**
 * Created by omg on 2018/7/23.
 * 此页面所有涉及到的设置通常应在应用启动后执行，且只需执行一次。
 * 此处仅为演示。
 */

public class CustomizeActivity extends BaseActivity {

    private AUTitleBar mTitle;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_customize);
        mTitle = (AUTitleBar) findViewById(R.id.titlebar);

        findViewById(R.id.btn_ua_setting).setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                enableUa();
                AUToast.makeToast(CustomizeActivity.this, R.string.setting_success, 2000).show();
            }
        });
        findViewById(R.id.btn_title_setting).setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                enableCustomizedTitle();
                AUToast.makeToast(CustomizeActivity.this, R.string.setting_success, 2000).show();
            }
        });
        findViewById(R.id.btn_menu_setting).setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                enableCustomizedMenu();
                AUToast.makeToast(CustomizeActivity.this, R.string.setting_success, 2000).show();
            }
        });
        findViewById(R.id.btn_progress_setting).setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                enableCustomizedProgress();
                AUToast.makeToast(CustomizeActivity.this, R.string.setting_success, 2000).show();
            }
        });
        findViewById(R.id.btn_pullrefresh_setting).setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                enableCustomizedPullRefresh();
                AUToast.makeToast(CustomizeActivity.this, R.string.setting_success, 2000).show();
            }
        });
        findViewById(R.id.btn_bg_setting).setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                enableCustomizedBackground();
                AUToast.makeToast(CustomizeActivity.this, R.string.setting_success, 2000).show();
            }
        });
        findViewById(R.id.btn_plugin_register).setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                registerJSAPI();
                AUToast.makeToast(CustomizeActivity.this, R.string.setting_success, 2000).show();
            }
        });
        findViewById(R.id.btn_jsapi_permission).setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                initJsApiPermission();
                AUToast.makeToast(CustomizeActivity.this, R.string.setting_success, 2000).show();
            }
        });
        findViewById(R.id.btn_plugin_url_intercept).setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                registerUrlInterceptPlugin();
                AUToast.makeToast(CustomizeActivity.this, R.string.setting_success, 2000).show();
            }
        });
        mTitle.setTitleText(getString(R.string.customize), (int) getResources().getDimension(com.mpaas.demo.sharedres.R.dimen.text_size)
                , getResources().getColor(com.mpaas.demo.sharedres.R.color.title_color));
        mTitle.getRightButtonIconView().setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                MenuPopupWindow popupWindow = new MenuPopupWindow(CustomizeActivity.this);
                popupWindow.showAsDropDown(mTitle.getRightButtonIconView(), 0, 0);
            }
        });
    }

    private void enableUa() {
        MPNebula.setUa(new H5UaProviderImpl());
    }

    private void enableCustomizedTitle() {
        // 此处必须设置标题栏资源所在的bundle名称，如果不设置，会出现资源无法加载导致标题栏无法生效
        H5Utils.setProvider(H5ReplaceResourceProvider.class.getName(), new H5ReplaceResourceProvider() {
            @Override
            public String getReplaceResourcesBundleName() {
                return BuildConfig.BUNDLE_NAME;
            }
        });
        MPNebula.setCustomViewProvider(new H5ViewProviderImpl());
    }

    private void enableCustomizedMenu() {
        MPNebula.setCustomViewProvider(new H5ViewProviderImpl2());
    }

    private void enableCustomizedProgress() {
        MPNebula.setCustomViewProvider(new H5ViewProviderImpl4());
    }

    private void enableCustomizedPullRefresh() {
        MPNebula.setCustomViewProvider(new H5ViewProviderImpl5());
    }

    /**
     * 完全自定义背景
     * <p>
     * 若仅需修改背景颜色，无需调用此方法
     * 只需在打开 H5 时传递参数：
     * Bundle bundle = new Bundle();
     * bundle.putInt(H5Param.LONG_BOUNCE_TOP_COLOR, getResources().getColor(R.color.xxxx));
     */
    private void enableCustomizedBackground() {
        MPNebula.setCustomViewProvider(new H5ViewProviderImpl3());
    }

    private void registerJSAPI() {
        MPNebula.registerH5Plugin(
                MyJSApiPlugin.class.getName(),
                BuildConfig.BUNDLE_NAME,
                "page",
                new String[]{"myapi1","myapi2",H5Plugin.CommonEvents.H5_PAGE_SHOULD_LOAD_URL}
        );
    }

    private void initJsApiPermission() {
        H5Utils.setProvider(H5JSApiPermissionProvider.class.getName(), new H5JSApiPermissionProviderImpl());
    }

    private void registerUrlInterceptPlugin() {
        MPNebula.registerH5Plugin(
                MyUrlInterceptPlugin.class.getName(),
                BuildConfig.BUNDLE_NAME,
                "page",
                new String[]{H5Plugin.CommonEvents.H5_PAGE_SHOULD_LOAD_URL}
        );
    }
}
