package com.mpaas.demo.nebula;

import android.os.Environment;

import com.alipay.mobile.common.logging.api.LoggerFactory;

import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.InputStream;
import java.util.HashMap;
import java.util.concurrent.ExecutorService;
import java.util.concurrent.Executors;

public class ResourceCache {
    public static final String TAG = "ResourceCache";
    private static final String sSavePath = Environment.getExternalStorageDirectory().getAbsolutePath() + "/mpaas_jtbank/";
    private static final HashMap<String, File> sFileMap = new HashMap<>();
    private static final ExecutorService sCachedThreadExecutor = Executors.newCachedThreadPool();

    public static void init() {
        LoggerFactory.getTraceLogger().debug(TAG, sSavePath);
        File dir = new File(sSavePath);
        if (!dir.exists()) {
            dir.mkdirs();
        }
        for (File file : dir.listFiles()) {
            sFileMap.put(fileNameToUrl(file.getName()), file);
            LoggerFactory.getTraceLogger().debug(TAG, "put file: " + file.getName());
        }
    }

    public static boolean contains(String url) {
        return null != sFileMap.get(url);
    }

    public static InputStream getResource(String url) {
        File file = sFileMap.get(url);
        try {
            return new FileInputStream(file);
        } catch (FileNotFoundException e) {
            e.printStackTrace();
        }
        return null;
    }

    public static void download(final String url) {
        sCachedThreadExecutor.execute(new Runnable() {
            @Override
            public void run() {
                HttpDownloader downloader = new HttpDownloader();
                int result = downloader.downloadFiles(url, sSavePath, urlToFileName(url));
                LoggerFactory.getTraceLogger().debug(TAG, "Download " + result + ": " + url);
                if (result == 0) {
                    sFileMap.put(url, new File(sSavePath, urlToFileName(url)));
                }
            }
        });
    }

    //https://mbanktest.95559.com.cn:8717/mobs/libs/require.text.js
    public static String urlToFileName(String url) {
        url = url.substring(36);
        url = url.replace("/", "___");
        return url;
    }

    public static String fileNameToUrl(String fileName) {
        fileName = fileName.replace("___", "/");
        return "https://mbanktest.95559.com.cn:8717/" + fileName;
    }
}
