package com.mpaas.demo.nebula.testcase;

import com.alipay.mobile.nebula.appcenter.download.H5DownloadRequest;
import com.mpaas.diagnose.CaseInfo;
import com.mpaas.diagnose.ICase;
import com.mpaas.nebula.adapter.api.MPNebula;
import com.mpaas.nebula.adapter.api.MpaasNebulaDownloadCallback;
import com.mpaas.nebula.adapter.api.MpaasNebulaInstallCallback;

import static com.mpaas.diagnose.CaseInfo.RESULT_CODE_FAIL;
import static com.mpaas.diagnose.CaseInfo.RESULT_CODE_SUCCESS;

public class AppDownloadCase implements ICase {
    private static AppDownloadCase sInstance;
    private CaseInfo mCaseInfo;

    private AppDownloadCase() {
    }

    public static AppDownloadCase getInstance() {
        if (sInstance == null) {
            synchronized (AppDownloadCase.class) {
                if (sInstance == null) {
                    sInstance = new AppDownloadCase();
                }
            }
        }
        return sInstance;
    }

    @Override
    public CaseInfo getCaseInfo() {
        if (mCaseInfo == null) {
            mCaseInfo = new CaseInfo(
                    "Nebula",
                    "Nebula-000010",
                    "检测离线包下载功能",
                    "自动检测离线包下载功能",
                    false
            );
        }
        return mCaseInfo;
    }

    @Override
    public void run() {
        MPNebula.downloadApp("90000000", new MpaasNebulaDownloadCallback() {
            @Override
            public void onFailed(H5DownloadRequest h5DownloadRequest, int errorCode, String errorMsg) {
                super.onFailed(h5DownloadRequest, errorCode, errorMsg);
                NebulaDiagnoseController.service.reportCase(AppDownloadCase.getInstance().getCaseInfo(), RESULT_CODE_FAIL, "下载失败：" + errorCode + " " + errorMsg);
            }

            @Override
            public void onFinish(H5DownloadRequest h5DownloadRequest, String savePath) {
                super.onFinish(h5DownloadRequest, savePath);
                NebulaDiagnoseController.service.reportCase(AppDownloadCase.getInstance().getCaseInfo(), RESULT_CODE_SUCCESS, "下载完成 存储路径：" + savePath);
            }

            @Override
            public void onAppHasDownloaded(String appId, String version) {
                super.onAppHasDownloaded(appId, version);
                NebulaDiagnoseController.service.reportCase(AppDownloadCase.getInstance().getCaseInfo(), RESULT_CODE_SUCCESS, appId + " " + version + " 已下载");
            }
        });
    }
}