package com.mpaas.demo.nebula.testcase;

import com.mpaas.diagnose.CaseInfo;
import com.mpaas.diagnose.ICase;
import com.mpaas.nebula.adapter.api.MPNebula;
import com.mpaas.nebula.adapter.api.MpaasNebulaInstallCallback;
import com.mpaas.nebula.adapter.api.MpaasNebulaUpdateCallback;

import static com.mpaas.diagnose.CaseInfo.RESULT_CODE_FAIL;
import static com.mpaas.diagnose.CaseInfo.RESULT_CODE_SUCCESS;

public class AppInstallCase implements ICase {
    private static AppInstallCase sInstance;
    private CaseInfo mCaseInfo;

    private AppInstallCase() {
    }

    public static AppInstallCase getInstance() {
        if (sInstance == null) {
            synchronized (AppInstallCase.class) {
                if (sInstance == null) {
                    sInstance = new AppInstallCase();
                }
            }
        }
        return sInstance;
    }

    @Override
    public CaseInfo getCaseInfo() {
        if (mCaseInfo == null) {
            mCaseInfo = new CaseInfo(
                    "Nebula",
                    "Nebula-000009",
                    "检测离线包安装功能",
                    "自动检测离线包安装功能",
                    false
            );
        }
        return mCaseInfo;
    }

    @Override
    public void run() {
        MPNebula.installApp("90000000",new MpaasNebulaInstallCallback(){
            @Override
            public void onResult(boolean success, boolean isPatch) {
                super.onResult(success, isPatch);
                if (success) {
                    NebulaDiagnoseController.service.reportCase(AppInstallCase.getInstance().getCaseInfo(), RESULT_CODE_SUCCESS, "");
                } else {
                    NebulaDiagnoseController.service.reportCase(AppInstallCase.getInstance().getCaseInfo(), RESULT_CODE_FAIL, "安装失败");
                }
            }

            @Override
            public void onAppHasInstalled(String appId, String version) {
                super.onAppHasInstalled(appId, version);
                NebulaDiagnoseController.service.reportCase(AppInstallCase.getInstance().getCaseInfo(), RESULT_CODE_SUCCESS, appId+" "+version+" 已安装");
            }
        });
    }
}