package com.mpaas.demo.nebula.testcase;

import com.mpaas.diagnose.DiagnoseService;
import com.mpaas.diagnose.IDiagnoseController;
import com.mpaas.diagnose.ILogListener;
import com.mpaas.framework.adapter.api.MPFramework;

import java.util.LinkedList;

public class NebulaDiagnoseController implements IDiagnoseController {

    public static DiagnoseService service;

    @Override
    public void init() {
        service = MPFramework.getExternalService(DiagnoseService.class.getName());
        registerLoadOfflineNebulaCase();
        registerVerifyCase();
        registerRegisterPlugin();
        registerUACase();
        registerUCCase();
        registerAppUpdateCase();
        registerAppDownloadCase();
        registerAppInstallCase();
        registerOpenH5Case();
        registerStoragePermissionCase();
        registerTinyAppCommonResCase();
        registerOpenTinyCase();
    }

    @Override
    public LinkedList<ILogListener> registerLogListeners() {
        LinkedList<ILogListener> listeners = new LinkedList<>();
        listeners.add(new H5AppCenterServiceImplLogListener());
        listeners.add(new H5PackageParserLogListener());
        listeners.add(new H5PluginConfigManagerLogListener());
        listeners.add(new H5WebViewLogListener());
        listeners.add(new H5PageDataLogListener());
        listeners.add(new H5WebViewClientLogListener());
        listeners.add(new H5GlobalDegradePkgLogListener());
        return listeners;
    }

    @Override
    public void runAllCase() {
        try {
            UACase.getInstance().run();
            LoadOfflineNebulaCase.getInstance().run();
            Thread.sleep(1000);
            RegisterPluginCase.getInstance().run();
            AppUpdateCase.getInstance().run();
            Thread.sleep(1000);
            AppDownloadCase.getInstance().run();
            Thread.sleep(1000);
            AppInstallCase.getInstance().run();
            Thread.sleep(1000);
            StoragePermissionCase.getInstance().run();
        } catch (InterruptedException e) {
            e.printStackTrace();
        }
    }

    private void registerLoadOfflineNebulaCase(){
        service.registerCase(LoadOfflineNebulaCase.getInstance().getCaseInfo());
    }

    private void registerVerifyCase() {
        service.registerCase(VerifyCase.getInstance().getCaseInfo());
    }

    private void registerRegisterPlugin() {
        service.registerCase(RegisterPluginCase.getInstance().getCaseInfo());
    }

    private void registerUACase() {
        service.registerCase(UACase.getInstance().getCaseInfo());
    }

    private void registerUCCase() {
        service.registerCase(UCCase.getInstance().getCaseInfo());
    }

    private void registerAppUpdateCase() {
        service.registerCase(AppUpdateCase.getInstance().getCaseInfo());
    }

    private void registerAppDownloadCase() {
        service.registerCase(AppDownloadCase.getInstance().getCaseInfo());
    }

    private void registerAppInstallCase() {
        service.registerCase(AppInstallCase.getInstance().getCaseInfo());
    }

    private void registerOpenH5Case() {
        service.registerCase(OpenH5Case.getInstance().getCaseInfo());
    }

    private void registerStoragePermissionCase() {
        service.registerCase(StoragePermissionCase.getInstance().getCaseInfo());
    }

    private void registerTinyAppCommonResCase() {
        service.registerCase(TinyAppCommonResCase.getInstance().getCaseInfo());
    }
    private void registerOpenTinyCase() {
        service.registerCase(OpenTinyCase.getInstance().getCaseInfo());
    }
}
