package com.mpaas.demo.nebula.testcase;

import android.Manifest;
import android.content.pm.PackageManager;

import com.mpaas.diagnose.CaseInfo;
import com.mpaas.diagnose.ICase;
import com.mpaas.framework.adapter.api.MPFramework;

import static com.mpaas.diagnose.CaseInfo.RESULT_CODE_FAIL;
import static com.mpaas.diagnose.CaseInfo.RESULT_CODE_SUCCESS;

public class StoragePermissionCase implements ICase {
    private static StoragePermissionCase sInstance;
    private CaseInfo mCaseInfo;

    private StoragePermissionCase() {
    }

    public static StoragePermissionCase getInstance() {
        if (sInstance == null) {
            synchronized (StoragePermissionCase.class) {
                if (sInstance == null) {
                    sInstance = new StoragePermissionCase();
                }
            }
        }
        return sInstance;
    }

    @Override
    public CaseInfo getCaseInfo() {
        if (mCaseInfo == null) {
            mCaseInfo = new CaseInfo(
                    "Nebula",
                    "Nebula-000008",
                    "检测是否已经获取存储权限",
                    "自动检测是否已经获取存储权限",
                    false
            );
        }
        return mCaseInfo;
    }

    @Override
    public void run() {
        if (PackageManager.PERMISSION_GRANTED
                == MPFramework.getApplicationContext().checkCallingOrSelfPermission(Manifest.permission.READ_EXTERNAL_STORAGE)) {

            NebulaDiagnoseController.service.reportCase(StoragePermissionCase.getInstance().getCaseInfo(), RESULT_CODE_SUCCESS, "");
        } else {
            NebulaDiagnoseController.service.reportCase(StoragePermissionCase.getInstance().getCaseInfo(), RESULT_CODE_FAIL, "未获取存储权限，小程序可能无法正常打开");
        }

    }
}
