package com.mpaas.demo.push;

import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;
import android.content.pm.ApplicationInfo;
import android.content.pm.PackageManager;
import android.os.Bundle;
import android.support.v4.content.LocalBroadcastManager;
import android.text.TextUtils;
import android.view.View;

import com.alipay.mobile.antui.basic.AUTitleBar;
import com.alipay.mobile.antui.status.AUResultView;
import com.alipay.mobile.common.logging.api.LoggerFactory;
import com.alipay.mobile.framework.LauncherApplicationAgent;
import com.alipay.mobile.framework.app.ui.BaseActivity;
import com.alipay.pushsdk.data.PushOsType;
import com.alipay.pushsdk.util.DeviceInfo;
import com.mpaas.demo.sharedres.MenuPopupWindow;
import com.mpaas.mps.adapter.api.MPPush;
import com.mpaas.mas.adapter.api.MPLogger;

import org.json.JSONException;
import org.json.JSONObject;

import java.util.HashMap;

import alipay.yunpushcore.rpc.ResultPbPB;

/**
 * Created by larry.cl.
 * 包含了push初始化，绑定用户id,解绑定用户id和上传第三方push token的示例。
 */

public class MainActivity extends BaseActivity {
    //根据自己用户系统的用户Id而定，这里以pushDemoUserId为例
    private String mUserId = null;
    private static final String TAG = "pushTag";
    //在manifest寻找指定key对应的数据
    private static final String APP_KEY = "appkey";
    private static final String MPAAS_API_KEY = "mpaasapi";
    private static final String ALI_PUSH_KEY = "ALIPUSH_APPID";
    private HashMap<String, String> mManifestMap;
    private static final String OPERATION_SUCCESS = "成功";
    private static final String OPERATION_FAILURE = "失败";
    private String appId = null;
    private String workspaceId = null;
    private static final String APP_VERSION = "1.0.0";
    private static final String CHANNEL = "alipay";

    private AUResultView mResult;
    private AUTitleBar mTitle;

    private NotificationHelper notificationHelper;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);
        bindViews();
        setListeners();
        init();
    }

    private void init() {
        //获取移动分析demo中提供的uid用于绑定push uid，保持统一，方便捞日志（捞日志基于该id值）。
        mUserId = getUserId();
        appId = getKeyFromManifest(getApplicationContext(), "mobilegw.appid");
        workspaceId = getKeyFromManifest(getApplicationContext(), "workspaceId");
        if (!TextUtils.isEmpty(workspaceId)) {
            workspaceId = workspaceId.substring(2);
        }
        LocalBroadcastManager.getInstance(this).registerReceiver(new BroadcastReceiver() {
            @Override
            public void onReceive(Context context, final Intent intent) {
                LoggerFactory.getTraceLogger().debug(TAG, "push localBroadcastManager onReceive : " + intent.getExtras().toString());
                mResult.setMainTitleText("push消息");
                int pushType = intent.getIntExtra("push_type", 0);
                if (pushType == PushMsgService.TYPE_INNER_PUSH_INIT) {
                    String token = intent.getStringExtra("push_token");
                    mResult.setThirdTitleText("内建渠道注册成功，adToken值为： " + token);
                } else if (pushType == PushMsgService.TYPE_THIRD_PUSH_INIT) {
                    String token = intent.getStringExtra("push_thirdToken");
                    int channel = intent.getIntExtra("push_channel", 0);
                    String platformChannel = "";
                    if (channel == PushOsType.XIAOMI.value()) {
                        platformChannel = "小米";
                    } else if (channel == PushOsType.HUAWEI.value()) {
                        platformChannel = "华为";
                    }
                    mResult.setThirdTitleText("第三方渠道 " + platformChannel + " 注册成功，adToken值为： " + token);
                } else if (pushType == PushMsgService.TYPE_MSG) {
                    String key = intent.getStringExtra("push_key");
                    String value = intent.getStringExtra("push_value");
                    mResult.setThirdTitleText("push消息的key值： " + key + "\n"
                            + "push消息的value值： " + value);
                    notifyNotification(value);
                }
            }
        }, new IntentFilter(PushMsgService.PUSH_SERVICE_ACTION));
        notificationHelper = new NotificationHelper(this);
    }

    private void setListeners() {
        findViewById(R.id.btn_init).setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                initPush();
            }
        });
        findViewById(R.id.btn_uploadThirdToken).setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                doUploadToken();
            }
        });
        findViewById(R.id.btn_bind).setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                doBind();
            }
        });
        findViewById(R.id.btn_unbind).setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                doUnBind();
            }
        });
        mTitle.getRightButtonIconView().setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                MenuPopupWindow popupWindow = new MenuPopupWindow(MainActivity.this);
                popupWindow.showAsDropDown(mTitle.getRightButtonIconView(), 0, 0);
            }
        });
    }

    private void bindViews() {
        mResult = (AUResultView) findViewById(R.id.result_view);
        mResult.setMainTitleText(getString(R.string.operation_result));
        mTitle = (AUTitleBar) findViewById(R.id.pushTitle);
        mTitle.setTitleText(getString(R.string.push_title), (int) getResources().getDimension(com.mpaas.demo.sharedres.R.dimen.text_size)
                , getResources().getColor(com.mpaas.demo.sharedres.R.color.title_color));
    }

    //初始化push
    private void initPush() {
        try {
            MPPush.init(getApplicationContext());
        } catch (Throwable throwable) {
            LoggerFactory.getTraceLogger().error(TAG, throwable.toString());
        }
    }

    //最好在子线程中调用绑定用户的相关操作
    private void doBind() {
        new Thread("bindUserThread") {
            @Override
            public void run() {
                doSimpleBind();
            }
        }.start();

    }

    // 绑定用户id和adtoken（封装后的简易接口，基于内置渠道标识）
    private void doSimpleBind() {
        final ResultPbPB resultPbPB = MPPush.bind(getApplicationContext()
                , mUserId, PushMsgService.mAdToken);
        handlePbPBResult("绑定用户操作", resultPbPB);
    }

    //最好在子线程中调用解除绑定用户的相关操作
    private void doUnBind() {
        new Thread("unBindUserThread") {
            @Override
            public void run() {
                doSimpleUnBind();
            }
        }.start();
    }

    //解除用户和adtoken 的绑定关系（封装后的简易接口）
    private void doSimpleUnBind() {
        final ResultPbPB resultPbPB = MPPush.unbind(getApplicationContext()
                , mUserId, PushMsgService.mAdToken);
        handlePbPBResult("解绑定用户操作", resultPbPB);
    }

    //最好在子线程中调用标识上报的相关操作
    private void doUploadToken() {
        new Thread() {
            @Override
            public void run() {
                doSimpleUploadToken();
            }
        }.start();
    }

    //第三方push标识的上报接口（封装后的简易接口）
    private void doSimpleUploadToken() {
        final ResultPbPB resultPbPB = MPPush.report(getApplicationContext(), PushMsgService.mAdToken
                /*channel可以选择XIAOMI,HUAWEI和GCM*/
                , PushOsType.HUAWEI.value(), PushMsgService.mThirdToken);
        handlePbPBResult("第三方push标识上报操作", resultPbPB);
    }

    private String model() {
        return "testPhone";
    }

    private String imei() {
        return DeviceInfo.getInstance(LauncherApplicationAgent.getInstance()
                .getBaseContext()).getImei();
    }

    private String imsi() {
        return DeviceInfo.getInstance(LauncherApplicationAgent.getInstance()
                .getBaseContext()).getImsi();
    }

    /**
     * 从manifest文件中读取meta-data的信息
     *
     * @param context
     * @param key
     * @return
     */

    private String getKeyFromManifest(Context context, String key) {
        if (mManifestMap == null) {
            mManifestMap = new HashMap<>();
        }
        try {
            ApplicationInfo appInfo = null;
            try {
                appInfo = context.getPackageManager().getApplicationInfo(context.getPackageName(), PackageManager.GET_META_DATA);
            } catch (Throwable e) {
                //do nothing
            }
            if (null != appInfo && null != appInfo.metaData) {
                String appKey = appInfo.metaData.getString(key);
                if (appKey == null || "".equals(appKey.trim())) {
                    appKey = null;
                } else {
                    appKey = appKey.trim();
                }
                mManifestMap.put(key, appKey);
                return appKey;
            }
        } catch (Throwable e) {
        }
        return null;
    }

    /**
     * @param operationType 操作类型
     * @param resultPbPB    push操作结果
     */

    private void handlePbPBResult(final String operationType, final ResultPbPB resultPbPB) {
        MainActivity.this.runOnUiThread(new Runnable() {
            @Override
            public void run() {
                if (resultPbPB.success) {
                    mResult.setMainTitleText(operationType + " " + OPERATION_SUCCESS);
                } else {
                    mResult.setMainTitleText(operationType + " " + OPERATION_FAILURE);
                }
                mResult.setThirdTitleText(resultPbPB.toString());
            }
        });
    }

    //获取移动分析demo中提供的uid
    private String getUserId() {
        String userId = MPLogger.getUserId();
        LoggerFactory.getTraceLogger().debug(TAG, "userId got is : " + userId);
        return userId;
    }

    private void notifyNotification(String value) {
        try {
            JSONObject valueJsonObject = new JSONObject(value);
            String title = valueJsonObject.getString("title");
            String content = valueJsonObject.getString("content");
            notificationHelper.notify(title, content);
        } catch (JSONException e) {
            e.printStackTrace();
        }
    }

}
