package com.mpaas.demo.push;

import android.content.Intent;
import android.support.v4.content.LocalBroadcastManager;
import android.text.TextUtils;

import com.alipay.mobile.common.logging.api.LoggerFactory;
import com.alipay.pushsdk.content.AliPushRcvService;
import com.alipay.pushsdk.data.BDataBean;
import com.alipay.pushsdk.push.PushAppInfo;

/**
 * Created by larry.cl.
 * push的接收服务
 */

public class PushMsgService extends AliPushRcvService {

    private static final String TAG = "pushTag";
    public static final String PUSH_SERVICE_ACTION = "tt-action";
    //推送消息的类型，用户自定义即可
    public static final int TYPE_MSG = -1;
    public static final int TYPE_INNER_PUSH_INIT = -2;
    public static final int TYPE_THIRD_PUSH_INIT = -3;
    //自建渠道推送标识
    public static String mAdToken = "";
    //第三方渠道推送标识
    public static String mThirdToken = "";

    public PushMsgService() {
        super();
    }

    /**
     * @param msgKey   消息推送的key
     * @param msgValue 消息推送的value
     * @param clicked  是否已经点击了
     *                 对于三方渠道来说clicked = true ,展示通知栏
     *                 对于自建渠道来说clicked = false，没有展示通知栏
     */
    @Override
    protected void handleActionReceived(String msgKey, String msgValue, boolean clicked) {
        Intent intent = new Intent(PUSH_SERVICE_ACTION);
        intent.putExtra("push_type", TYPE_MSG);
        intent.putExtra("push_key", msgKey);
        intent.putExtra("push_value", msgValue);
        LocalBroadcastManager.getInstance(this).sendBroadcast(intent);
        LoggerFactory.getTraceLogger().debug(TAG, "onHandleIntent sendLocalBroadcast: " + intent.toString());
        if (TextUtils.isEmpty(msgValue)) {
            return;
        }
        if (clicked) {
            BDataBean bDataBean = BDataBean.create(msgValue);
            if (bDataBean == null) {
                return;
            }
            bDataBean.action(this);
        } else {
            // show your notification and handle action
        }

    }

    /**
     * @param adToken 自建渠道的推送标识
     */

    @Override
    protected void handleActionId(String adToken) {
        PushAppInfo pushAppInfo = new PushAppInfo(getApplicationContext());
        pushAppInfo.setAppToken(adToken);
        LoggerFactory.getTraceLogger().debug(TAG, "自建渠道的adToken: " + adToken);
        Intent intent = new Intent(PUSH_SERVICE_ACTION);
        intent.putExtra("push_type", TYPE_INNER_PUSH_INIT);
        intent.putExtra("push_token", adToken);
        LocalBroadcastManager.getInstance(this).sendBroadcast(intent);
        mAdToken = adToken;
    }

    /**
     * @param thirdToken   三方渠道的推送标识
     * @param platformType 三方渠道的类型 华为=5 小米=4
     */
    @Override
    protected void handleActionThirdId(String thirdToken, int platformType) {
        LoggerFactory.getTraceLogger().debug(TAG, "第三方渠道的adToken: " + thirdToken + "platformType: " + platformType);
        Intent intent = new Intent(PUSH_SERVICE_ACTION);
        intent.putExtra("push_type", TYPE_THIRD_PUSH_INIT);
        intent.putExtra("push_thirdToken", thirdToken);
        intent.putExtra("push_channel", platformType);
        LocalBroadcastManager.getInstance(this).sendBroadcast(intent);
        mThirdToken = thirdToken;
    }
}
