package com.mpaas.demo.push.testcase;

import android.content.Context;
import android.content.pm.ApplicationInfo;
import android.content.pm.PackageManager;
import android.text.TextUtils;

import com.alipay.mobile.common.logging.api.LoggerFactory;
import com.alipay.mobile.framework.LauncherApplicationAgent;
import com.mpaas.diagnose.DiagnoseService;
import com.mpaas.diagnose.IDiagnoseController;
import com.mpaas.framework.adapter.api.MPFramework;
import com.mpaas.mpaasadapter.api.MPLogger;
import com.mpaas.mps.adapter.api.MPPush;
import com.mpaas.diagnose.ILogListener;

import java.util.HashMap;
import java.util.LinkedList;

/**
 * Created by larry.cl.
 */
public class PushDiagnoseController implements IDiagnoseController {

    public static final String ALI_PUSH_KEY = "ALIPUSH_APPID";
    public static final int TYPE_MSG = -1;
    public static final int TYPE_INNER_PUSH_INIT = -2;
    public static final int TYPE_THIRD_PUSH_INIT = -3;
    public static final String PUSH_SERVICE_ACTION = "tt-action";
    public static final String TAG = "PushTC";
    public static String appId;
    public static String workspaceId;
    public static DiagnoseService service;
    public static boolean pushCase1 = false;
    public static boolean pushCase2 = false;
    public static boolean pushCase3 = false;
    private HashMap<String, String> mManifestMap;

    public static String getMetaData(Context context, String key) throws PackageManager.NameNotFoundException {
        ApplicationInfo appInfo = context.getPackageManager()
                .getApplicationInfo(context.getPackageName(),
                        PackageManager.GET_META_DATA);
        String value = appInfo.metaData.get(key).toString();
        return value;
    }

    public static String getUserId() {
        String userId = MPLogger.getUserId();
        LoggerFactory.getTraceLogger().debug(TAG, "userId got is : " + userId);
        return userId;
    }

    @Override
    public void init() {
        appId = getKeyFromManifest(LauncherApplicationAgent.getInstance().getApplicationContext(), "mobilegw.appid");
        workspaceId = getKeyFromManifest(LauncherApplicationAgent.getInstance().getApplicationContext(), "workspaceId");
        if (!TextUtils.isEmpty(workspaceId)) {
            workspaceId = workspaceId.substring(2);
        }
        service = MPFramework.getExternalService(DiagnoseService.class.getName());
        registerPushInitCase();
    }

    @Override
    public LinkedList<ILogListener> registerLogListeners() {
        return new LinkedList<>();
    }

    @Override
    public void runAllCase() {
        try {
            MPPush.init(LauncherApplicationAgent.getInstance().getApplicationContext());
        } catch (Throwable throwable) {
            LoggerFactory.getTraceLogger().error(TAG, throwable.toString());
        }
        PushInitAndPushCase.getInstance().run();
        PushInitAndBindCase.getInstance().run();
        PushInitAndUnbindCase.getInstance().run();
        PushThirdInitAndPushCase.getInstance().run();
    }

    /**
     * 手动测试顺序：
     * 1、根据userId推送消息(title,content,param的key均需设置为1)，PushInitAndPushCase和PushInitAndBindCase同时能通过则OK
     * 2、前两个通过后，PushInitAndUnbindCase线程会Unbind，这时通过步骤1的userId无法推送且再通过adToken推送成功则ok
     * 3、第三方推送需要手动点击通知栏才会触发消息回调
     */
    private void registerPushInitCase() {
        service.registerCase(PushThirdInitAndPushCase.getInstance().getCaseInfo());
        service.registerCase(PushInitAndPushCase.getInstance().getCaseInfo());
        service.registerCase(PushInitAndBindCase.getInstance().getCaseInfo());
        service.registerCase(PushInitAndUnbindCase.getInstance().getCaseInfo());

    }

    private String getKeyFromManifest(Context context, String key) {
        if (mManifestMap == null) {
            mManifestMap = new HashMap<>();
        }
        try {
            ApplicationInfo appInfo = null;
            try {
                appInfo = context.getPackageManager().getApplicationInfo(context.getPackageName(), PackageManager.GET_META_DATA);
            } catch (Throwable e) {
                //do nothing
            }
            if (null != appInfo && null != appInfo.metaData) {
                String appKey = appInfo.metaData.getString(key);
                if (appKey == null || "".equals(appKey.trim())) {
                    appKey = null;
                } else {
                    appKey = appKey.trim();
                }
                mManifestMap.put(key, appKey);
                return appKey;
            }
        } catch (Throwable e) {
        }
        return null;
    }

}
