package com.mpaas.demo.push.testcase;

import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;
import android.support.v4.content.LocalBroadcastManager;
import android.text.TextUtils;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.alipay.mobile.common.logging.api.LoggerFactory;
import com.alipay.mobile.framework.LauncherApplicationAgent;
import com.alipay.pushsdk.data.PushOsType;
import com.mpaas.diagnose.CaseInfo;
import com.mpaas.diagnose.ICase;
import com.mpaas.mps.adapter.api.MPPush;

import alipay.yunpushcore.rpc.ResultPbPB;

import static com.mpaas.demo.push.testcase.PushDiagnoseController.TAG;
import static com.mpaas.diagnose.CaseInfo.RESULT_CODE_SUCCESS;

/**
 * Created by larry.cl.
 */
public class PushInitAndUnbindCase implements ICase {

    private static PushInitAndUnbindCase sInstance;
    private CaseInfo mCaseInfo;
    private String adToken;
    private String thirdAdToken;
    private boolean flag = true;

    public static PushInitAndUnbindCase getInstance() {
        if (sInstance == null) {
            synchronized (PushInitAndUnbindCase.class) {
                if (sInstance == null) {
                    sInstance = new PushInitAndUnbindCase();
                }
            }
        }
        return sInstance;
    }

    @Override
    public CaseInfo getCaseInfo() {
        if (mCaseInfo == null) {
            mCaseInfo = new CaseInfo(
                    "Push",
                    "Push-000003",
                    "检测Push解绑定以及推送功能",
                    "手动检测Push解绑定以及推送功能",
                    true
            );
        }
        return mCaseInfo;
    }

    @Override
    public void run() {
        LocalBroadcastManager.getInstance(LauncherApplicationAgent.getInstance().getApplicationContext()).registerReceiver(new BroadcastReceiver() {
            @Override
            public void onReceive(Context context, final Intent intent) {
                int pushType = intent.getIntExtra("push_type", 0);
                if (pushType == PushDiagnoseController.TYPE_INNER_PUSH_INIT) {
                    String token = intent.getStringExtra("push_token");
                    adToken = token;
                    LoggerFactory.getTraceLogger().info(TAG, "adToken : " + token);
                } else if (pushType == PushDiagnoseController.TYPE_THIRD_PUSH_INIT) {
                    String token = intent.getStringExtra("push_thirdToken");
                    thirdAdToken = token;
                    int channel = intent.getIntExtra("push_channel", 0);
                    String platformChannel = "";
                    if (channel == PushOsType.XIAOMI.value()) {
                        platformChannel = "小米";
                    } else if (channel == PushOsType.HUAWEI.value()) {
                        platformChannel = "华为";
                    }
                    LoggerFactory.getTraceLogger().info(TAG, "third_push : " +
                            platformChannel + ":" + token);
                } else if (pushType == PushDiagnoseController.TYPE_MSG) {
                    if (flag) {
                        flag = false;
                        doSimpleUnBind(adToken);
                    } else {
                        String key = intent.getStringExtra("push_key");
                        String value = intent.getStringExtra("push_value");
                        JSONObject pushMessageJson = JSON.parseObject(value);
                        if (!TextUtils.isEmpty(adToken) && TextUtils.isEmpty(thirdAdToken) &&
                                pushMessageJson != null && "1".equals(pushMessageJson.getString("title"))
                                && "1".equals(pushMessageJson.getString("content")) &&
                                "1".equals(((JSONObject) pushMessageJson.get("params")).getString("key"))) {
                            LoggerFactory.getTraceLogger().info(TAG, "push_message : " + key
                                    + "_" + value);
                            PushDiagnoseController.service.reportCase(PushInitAndUnbindCase.getInstance().getCaseInfo(), RESULT_CODE_SUCCESS, "自建渠道成功收到推送消息");
                        }
                    }
                }
            }
        }, new IntentFilter(PushDiagnoseController.PUSH_SERVICE_ACTION));

    }

    private void doSimpleUnBind(final String adToken) {
        new Thread("unBindUserThread") {
            @Override
            public void run() {
                while (true) {
                    if (PushDiagnoseController.pushCase1 &&
                            PushDiagnoseController.pushCase2) {
                        String userId = PushDiagnoseController.getUserId();
                        final ResultPbPB resultPbPB = MPPush.unbind(LauncherApplicationAgent.getInstance().getApplicationContext(),
                                userId, adToken);
                        LoggerFactory.getTraceLogger().info(TAG, "unbind userId : " + userId);
                        LoggerFactory.getTraceLogger().info(TAG, "UNBIND ResultPbPB : " + resultPbPB.toString());
                        return;
                    }
                }
            }
        }.start();
    }

}
