package com.mpaas.demo.push.testcase;

import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;
import android.support.v4.content.LocalBroadcastManager;
import android.text.TextUtils;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.alipay.mobile.common.logging.api.LoggerFactory;
import com.alipay.mobile.framework.LauncherApplicationAgent;
import com.alipay.pushsdk.data.PushOsType;
import com.mpaas.diagnose.CaseInfo;
import com.mpaas.diagnose.ICase;
import com.mpaas.mps.adapter.api.MPPush;

import static com.mpaas.demo.push.testcase.PushDiagnoseController.TAG;
import static com.mpaas.diagnose.CaseInfo.RESULT_CODE_SUCCESS;

/**
 * Created by larry.cl.
 */
public class PushThirdInitAndPushCase implements ICase {

    private static PushThirdInitAndPushCase sInstance;
    private CaseInfo mCaseInfo;
    private String adToken;
    private String thirdAdToken;

    public static PushThirdInitAndPushCase getInstance() {
        if (sInstance == null) {
            synchronized (PushThirdInitAndPushCase.class) {
                if (sInstance == null) {
                    sInstance = new PushThirdInitAndPushCase();
                }
            }
        }
        return sInstance;
    }

    @Override
    public CaseInfo getCaseInfo() {
        if (mCaseInfo == null) {
            mCaseInfo = new CaseInfo(
                    "Push",
                    "Push-000001",
                    "检测第三方Push初始化和推送功能",
                    "手动检测第三方Push初始化和推送功能",
                    false
            );
        }
        return mCaseInfo;
    }

    @Override
    public void run() {
        LocalBroadcastManager.getInstance(LauncherApplicationAgent.getInstance().getApplicationContext()).registerReceiver(new BroadcastReceiver() {
            @Override
            public void onReceive(Context context, final Intent intent) {
                int pushType = intent.getIntExtra("push_type", 0);
                if (pushType == PushDiagnoseController.TYPE_INNER_PUSH_INIT) {
                    String token = intent.getStringExtra("push_token");
                    adToken = token;
                    LoggerFactory.getTraceLogger().info(TAG, "adToken : " + token);
                } else if (pushType == PushDiagnoseController.TYPE_THIRD_PUSH_INIT) {
                    String token = intent.getStringExtra("push_thirdToken");
                    thirdAdToken = token;
                    int channel = intent.getIntExtra("push_channel", 0);
                    String platformChannel = "";
                    if (channel == PushOsType.XIAOMI.value()) {
                        platformChannel = "小米";
                    } else if (channel == PushOsType.HUAWEI.value()) {
                        platformChannel = "华为";
                    }
                    LoggerFactory.getTraceLogger().info(TAG, "third_push : " +
                            platformChannel + ":" + token);
                } else if (pushType == PushDiagnoseController.TYPE_MSG) {
                    String key = intent.getStringExtra("push_key");
                    String value = intent.getStringExtra("push_value");
                    LoggerFactory.getTraceLogger().info(TAG, "push_message : " + key
                            + "_" + value);
                    JSONObject pushMessageJson = JSON.parseObject(value);
                    if (!TextUtils.isEmpty(adToken) && !TextUtils.isEmpty(thirdAdToken) &&
                            pushMessageJson != null && "1".equals(pushMessageJson.getString("title"))
                            && "1".equals(pushMessageJson.getString("content")) &&
                            "1".equals(((JSONObject) pushMessageJson.get("params")).get("key"))) {
                        LoggerFactory.getTraceLogger().info(TAG, "push_message : " + key
                                + "_" + value);
                        PushDiagnoseController.service.reportCase(PushThirdInitAndPushCase.getInstance().getCaseInfo(), RESULT_CODE_SUCCESS, "三方渠道成功收到推送消息");
                    }
                }
            }
        }, new IntentFilter(PushDiagnoseController.PUSH_SERVICE_ACTION));

        try {
            MPPush.init(LauncherApplicationAgent.getInstance().getApplicationContext());
        } catch (Throwable throwable) {
            LoggerFactory.getTraceLogger().error(TAG, throwable.toString());
        }

    }

}
