package com.mpaas.demo.rpc;

import android.app.Activity;
import android.os.Bundle;
import android.view.View;
import android.widget.Toast;

import com.alipay.mobile.antui.basic.AUTitleBar;
import com.alipay.mobile.antui.basic.AUToast;
import com.alipay.mobile.common.rpc.RpcException;
import com.alipay.mobile.common.rpc.RpcInvokeContext;
import com.alipay.mobile.framework.service.annotation.OperationType;
import com.alipay.mobile.framework.service.common.RpcService;
import com.alipay.mobile.framework.service.common.TaskScheduleService;
import com.mpaas.demo.rpc.model.AccountInfo;
import com.mpaas.demo.rpc.model.UserInfo;
import com.mpaas.demo.rpc.request.GetIdGetReq;
import com.mpaas.demo.rpc.request.PostPostReq;
import com.mpaas.demo.sharedres.MenuPopupWindow;
import com.mpaas.framework.adapter.api.MPFramework;

import java.util.HashMap;
import java.util.Map;

/**
 * Created by xingcheng on 2018/7/27.
 */

public class RpcActivity extends Activity {

    private TaskScheduleService taskService;
    private RpcDemoClient demoClient;

    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_rpc);

        taskService = MPFramework.getExternalService(TaskScheduleService.class.getName());
        RpcService rpcService = MPFramework.getExternalService(RpcService.class.getName());
        demoClient = rpcService.getRpcProxy(RpcDemoClient.class);

        initView();
        initRpcConfig(rpcService);
    }

    private void initView() {
        final AUTitleBar titleBar = (AUTitleBar) findViewById(R.id.rpc_title);
        titleBar.setTitleText(getString(R.string.rpc_title), (int)getResources().getDimension(com.mpaas.demo.sharedres.R.dimen.text_size)
                , getResources().getColor(com.mpaas.demo.sharedres.R.color.title_color));
        titleBar.getRightButtonIconView().setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                MenuPopupWindow popupWindow = new MenuPopupWindow(RpcActivity.this);
                popupWindow.showAsDropDown(titleBar.getRightButtonIconView(), 0, 0);
            }
        });

        findViewById(R.id.btn_get).setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                testGet();
            }
        });
        findViewById(R.id.btn_post).setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                testPost();
            }
        });
        findViewById(R.id.btn_exception).setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                testException();
            }
        });
    }

    private void initRpcConfig(RpcService rpcService) {
        RpcInvokeContext rpcInvokeContext = rpcService.getRpcInvokeContext(demoClient);

        // 设置超时时间，单位ms
        rpcInvokeContext.setTimeout(60000);

        // 设置网关地址，如果不设置将以 portal 工程中的 AndroidManifest.xml 为准
//        String gwUrl = "https://cn-hangzhou-mgs-gw.cloud.alipay.com/mgw.htm";
//        rpcInvokeContext.setGwUrl(gwUrl);

        //设置请求头
        Map<String,String> headerMap = new HashMap<>();
        headerMap.put("key1","val1");
        headerMap.put("key2","val2");
        rpcInvokeContext.setRequestHeaders(headerMap);

        // 设置rpc拦截器
        // 全局设置，可在 MockLauncherApplicationAgent.postInit() 中设置
        rpcService.addRpcInterceptor(OperationType.class, new CommonInterceptor());
    }

    private void testGet() {
        // rpc请求是同步的，这里使用了 mpaas 框架提供的线程池
        // 开发者也可使用自己的线程池
        taskService.parallelExecute(new Runnable() {
            @Override
            public void run() {
                try {
                    GetIdGetReq req = new GetIdGetReq();
                    req.id = "123";
                    req.age = 14;
                    req.isMale = true;
                    String result = demoClient.getIdGet(req);

                    showToast(result, true);
                } catch (RpcException e) {
                    showToast(e.getMessage(), false);

                    // rpc错误码
                    int errorCode = e.getCode();

                    // rpc错误信息
                    String errorMsg = e.getMsg();

                    // 判断是本地网络错误，还是服务端错误
                    if (e.isClientError()) {

                    } else {

                    }
                }
            }
        }, "rpc-get");
    }

    private void testPost() {
        taskService.parallelExecute(new Runnable() {
            @Override
            public void run() {
                try {
                    AccountInfo accountInfo = new AccountInfo();
                    accountInfo.username = "123@alipay.com";
                    accountInfo.password = "123456";
                    PostPostReq req = new PostPostReq();
                    req._requestBody = accountInfo;
                    UserInfo userInfo = demoClient.postPost(req);

                    showToast("vip level: " + userInfo.vipInfo.level, true);
                } catch (RpcException e) {
                    showToast(e.getMessage(), false);
                }
            }
        }, "rpc-post");
    }

    private void testException() {
        taskService.parallelExecute(new Runnable() {
            @Override
            public void run() {
                String result = demoClient.exceptionGet();
                if (result != null) {
                    showToast(result, true);
                }
            }
        }, "rpc-exception");
    }

    private void showToast(final String text, final boolean success) {
        runOnUiThread(new Runnable() {
            @Override
            public void run() {
                AUToast.makeToast(RpcActivity.this, success ?
                        com.alipay.mobile.antui.R.drawable.toast_ok :
                        com.alipay.mobile.antui.R.drawable.toast_false, text, Toast.LENGTH_SHORT).show();
            }
        });
    }


}
