package com.mpaas.demo.rpc.testcase;

import com.alipay.mobile.common.rpc.RpcException;
import com.mpaas.demo.rpc.testcase.request.GetIdGetReq;
import com.mpaas.diagnose.CaseInfo;
import com.mpaas.diagnose.ICase;

import org.json.JSONException;
import org.json.JSONObject;

import static com.mpaas.diagnose.CaseInfo.RESULT_CODE_FAIL;
import static com.mpaas.diagnose.CaseInfo.RESULT_CODE_SUCCESS;

/**
 * Created by larry.cl.
 */
public class GetCase implements ICase {

    private static GetCase sInstance;
    private CaseInfo mCaseInfo;

    private GetCase() {

    }

    public static GetCase getInstance() {
        if (sInstance == null) {
            synchronized (GetCase.class) {
                if (sInstance == null) {
                    sInstance = new GetCase();
                }
            }
        }
        return sInstance;
    }

    @Override
    public CaseInfo getCaseInfo() {
        if (mCaseInfo == null) {
            mCaseInfo = new CaseInfo(
                    "Rpc",
                    "Rpc-000000",
                    "检测Rpc Get功能",
                    "自动检测Rpc Get功能",
                    false
            );
        }
        return mCaseInfo;
    }

    @Override
    public void run() {
        try {
            GetIdGetReq req = new GetIdGetReq();
            req.id = "123";
            req.age = 14;
            req.isMale = true;
            String result = RpcDiagnoseController.demoClient.getGet(req);
            try {
                JSONObject jsonObject = new JSONObject(result);
                if (jsonObject != null && "20".equals(jsonObject.getString("age"))) {
                    RpcDiagnoseController.service.reportCase(GetCase.getInstance().getCaseInfo(), RESULT_CODE_SUCCESS, "get请求成功");
                } else {
                    RpcDiagnoseController.service.reportCase(GetCase.getInstance().getCaseInfo(), RESULT_CODE_FAIL, "get请求失败");
                }
            } catch (JSONException e) {
                e.printStackTrace();
                RpcDiagnoseController.service.reportCase(GetCase.getInstance().getCaseInfo(), RESULT_CODE_FAIL, "get请求失败");
            }
        } catch (RpcException e) {
            RpcDiagnoseController.service.reportCase(GetCase.getInstance().getCaseInfo(), RESULT_CODE_FAIL, "get请求失败");
            // rpc错误码
            int errorCode = e.getCode();

            // rpc错误信息
            String errorMsg = e.getMsg();

            // 判断是本地网络错误，还是服务端错误
            if (e.isClientError()) {

            } else {

            }
        }
    }
}
