package com.mpaas.demo.rpc.testcase;

import com.alipay.mobile.common.rpc.RpcException;
import com.mpaas.demo.rpc.testcase.model.AccountInfo;
import com.mpaas.demo.rpc.testcase.model.UserInfo;
import com.mpaas.demo.rpc.testcase.request.PostPostReq;
import com.mpaas.diagnose.CaseInfo;
import com.mpaas.diagnose.ICase;

import static com.mpaas.demo.rpc.testcase.RpcDiagnoseController.demoClient;
import static com.mpaas.diagnose.CaseInfo.RESULT_CODE_FAIL;
import static com.mpaas.diagnose.CaseInfo.RESULT_CODE_SUCCESS;

/**
 * Created by larry.cl.
 */
public class PostCase implements ICase {

    private static PostCase sInstance;
    private CaseInfo mCaseInfo;

    private PostCase() {

    }

    public static PostCase getInstance() {
        if (sInstance == null) {
            synchronized (PostCase.class) {
                if (sInstance == null) {
                    sInstance = new PostCase();
                }
            }
        }
        return sInstance;
    }

    @Override
    public CaseInfo getCaseInfo() {
        if (mCaseInfo == null) {
            mCaseInfo = new CaseInfo(
                    "Rpc",
                    "Rpc-000001",
                    "检测Rpc Post功能",
                    "自动检测Rpc Post功能",
                    false
            );
        }
        return mCaseInfo;
    }

    @Override
    public void run() {
        try {
            AccountInfo accountInfo = new AccountInfo();
            accountInfo.username = "123@alipay.com";
            accountInfo.password = "123456";
            PostPostReq req = new PostPostReq();
            req._requestBody = accountInfo;
            UserInfo userInfo = demoClient.postPost(req);
            if (userInfo != null && userInfo.vipInfo != null
                    && userInfo.vipInfo.level == 101) {
                RpcDiagnoseController.service.reportCase(PostCase.getInstance().getCaseInfo(), RESULT_CODE_SUCCESS, "post请求成功");
            } else {
                RpcDiagnoseController.service.reportCase(PostCase.getInstance().getCaseInfo(), RESULT_CODE_FAIL, "post请求失败");
            }
        } catch (RpcException e) {
            RpcDiagnoseController.service.reportCase(PostCase.getInstance().getCaseInfo(), RESULT_CODE_FAIL, "post请求失败");
        }
    }
}
