package com.mpaas.demo.rpc.testcase;

import com.alipay.mobile.common.rpc.RpcInvokeContext;
import com.alipay.mobile.framework.service.annotation.OperationType;
import com.alipay.mobile.framework.service.common.RpcService;
import com.mpaas.diagnose.DiagnoseService;
import com.mpaas.diagnose.IDiagnoseController;
import com.mpaas.diagnose.ILogListener;
import com.mpaas.framework.adapter.api.MPFramework;

import java.util.HashMap;
import java.util.LinkedList;
import java.util.Map;

/**
 * Created by larry.cl.
 */
public class RpcDiagnoseController implements IDiagnoseController {

    public static DiagnoseService service;
    public static RpcDemoClient demoClient;
    public static RpcInvokeContext rpcInvokeContext;
    public static RpcService rpcService;

    @Override
    public void init() {
        service = MPFramework.getExternalService(DiagnoseService.class.getName());
        rpcService = MPFramework.getExternalService(RpcService.class.getName());
        demoClient = rpcService.getRpcProxy(RpcDemoClient.class);
        rpcInvokeContext = rpcService.getRpcInvokeContext(demoClient);
        initConfig();
        registerAllCase();
    }

    @Override
    public LinkedList<ILogListener> registerLogListeners() {
        return new LinkedList<>();
    }

    @Override
    public void runAllCase() {
        GetCase.getInstance().run();
        PostCase.getInstance().run();
        ExceptionCase.getInstance().run();
        //目前只验证了requestheader配置数据，timeout值无接口获取验证
        ConfigCase.getInstance().run();
    }

    private void registerAllCase() {
        service.registerCase(GetCase.getInstance().getCaseInfo());
        service.registerCase(PostCase.getInstance().getCaseInfo());
        service.registerCase(ExceptionCase.getInstance().getCaseInfo());
        service.registerCase(ConfigCase.getInstance().getCaseInfo());
    }

    private void initConfig() {
        // 设置超时时间，单位ms
        rpcInvokeContext.setTimeout(60000);

        //设置请求头
        Map<String, String> headerMap = new HashMap<>();
        headerMap.put("key1", "val1");
        headerMap.put("key2", "val2");
        rpcInvokeContext.setRequestHeaders(headerMap);

        // 设置rpc拦截器
        // 全局设置，可在 MockLauncherApplicationAgent.postInit() 中设置
        rpcService.addRpcInterceptor(OperationType.class, new CommonInterceptor());
    }

}
