package com.mpaas.demo.scan;

import android.app.Activity;
import android.content.Intent;
import android.os.Bundle;
import android.support.annotation.Nullable;
import android.view.View;
import android.widget.Toast;

import com.alipay.android.phone.scancode.export.ScanCallback;
import com.alipay.android.phone.scancode.export.ScanRequest;
import com.alipay.android.phone.scancode.export.ScanService;
import com.alipay.mobile.antui.basic.AUTitleBar;
import com.alipay.mobile.antui.basic.AUToast;
import com.alipay.mobile.antui.dialog.AUNoticeDialog;
import com.alipay.mobile.framework.LauncherApplicationAgent;
import com.mpaas.demo.custom.ScanHelper;
import com.mpaas.demo.sharedres.MenuPopupWindow;

/**
 * Created by xingcheng on 2018/8/8.
 */

public class ScanActivity extends Activity {
    private AUTitleBar mTitle;

    @Override
    protected void onCreate(@Nullable Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_scan);

        mTitle = ((AUTitleBar) findViewById(R.id.scan_title));
        mTitle.setTitleText(getString(R.string.scan_title), (int) getResources().getDimension(com.mpaas.demo.sharedres.R.dimen.text_size)
                , getResources().getColor(com.mpaas.demo.sharedres.R.color.title_color));
        mTitle.getRightButtonIconView().setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                MenuPopupWindow popupWindow = new MenuPopupWindow(ScanActivity.this);
                popupWindow.showAsDropDown(mTitle.getRightButtonIconView(), 0, 0);
            }
        });

        findViewById(R.id.standard_ui_btn).setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                scanWithStandardUI();
            }
        });

        findViewById(R.id.custom_ui_btn).setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                scanWithCustomUI();
            }
        });
    }

    private void scanWithStandardUI() {
        ScanService service = LauncherApplicationAgent.getInstance().getMicroApplicationContext()
                .findServiceByInterface(ScanService.class.getName());
        ScanRequest scanRequest = new ScanRequest();
        scanRequest.setScanType(ScanRequest.ScanType.QRCODE);
        // 设置扫码界面 title
        scanRequest.setmTitleText(getString(R.string.standard_title));
        // 设置扫码窗口下提示文字
//        scanRequest.setViewText("");

        service.scan(this, scanRequest, new ScanCallback() {
            @Override
            public void onScanResult(final boolean isProcessed, final Intent result) {
                if (!isProcessed) {
                    // 扫码界面点击物理返回键或左上角返回键
                    return;
                }

                // 注意：本回调是在子线程中执行
                runOnUiThread(new Runnable() {
                    @Override
                    public void run() {
                        if (result == null || result.getData() == null) {
                            AUToast.makeToast(ScanActivity.this,
                                    com.alipay.mobile.antui.R.drawable.toast_false, R.string.scan_failure, Toast.LENGTH_SHORT).show();
                            return;
                        }
                        alert(result.getData().toString());
                    }
                });
            }
        });
    }

    private void scanWithCustomUI() {
        ScanHelper.getInstance().scan(this, new ScanHelper.ScanCallback() {
            @Override
            public void onScanResult(boolean isProcessed, Intent result) {
                if (!isProcessed) {
                    // 扫码界面点击物理返回键或左上角返回键
                    return;
                }

                if (result == null || result.getData() == null) {
                    AUToast.makeToast(ScanActivity.this,
                            com.alipay.mobile.antui.R.drawable.toast_false, R.string.scan_failure, Toast.LENGTH_SHORT).show();
                    return;
                }
                alert(result.getData().toString());
            }
        });
    }

    private void alert(String msg) {
        AUNoticeDialog dialog = new AUNoticeDialog(
                this, "", msg, getString(R.string.confirm), "");
        dialog.show();
    }
}
