package com.mpaas.demo.sharedres;

import android.content.Context;
import android.graphics.drawable.ColorDrawable;
import android.os.Bundle;
import android.view.View;
import android.view.ViewGroup;
import android.widget.PopupWindow;
import android.widget.TextView;

import com.alipay.mobile.framework.LauncherApplicationAgent;
import com.alipay.mobile.h5container.api.H5Bundle;
import com.alipay.mobile.h5container.api.H5Param;
import com.alipay.mobile.h5container.service.H5Service;

public class MenuPopupWindow extends PopupWindow implements View.OnClickListener {

    private ViewGroup mRootView;
    private Context mContext;

    private static final String MPAAS_DOC = "https://www.cloud.alipay.com/docs/2/63785";
    private static final String ANT_FINANCIAL_CLOUD = "https://www.cloud.alipay.com/";

    public MenuPopupWindow(Context context) {
        mContext = context;
        init(context);
    }

    public void init(Context context) {
        String[] items = context.getResources().getStringArray(R.array.menu_items);
        mRootView = (ViewGroup) View.inflate(context, R.layout.root_menupopupwindow, null);
        for (int i = 0; i < items.length; i++) {
            View view = View.inflate(context, R.layout.item_root_menupopupwindow, null);
            TextView tvItem = (TextView) view.findViewById(R.id.tvItem);
            View dividerLine = view.findViewById(R.id.v_line);
            tvItem.setText(items[i]);
            if (i == 0) {
                tvItem.setId(R.id.item_ant_cloud);
            } else if (i == 1) {
                tvItem.setId(R.id.item_mpaas_doc);
            }
            tvItem.setOnClickListener(this);
            if (i == 0) {
                dividerLine.setVisibility(View.INVISIBLE);
            } else {
                dividerLine.setVisibility(View.VISIBLE);
            }
            mRootView.addView(view);
        }
        setContentView(mRootView);
        setWidth(ViewGroup.LayoutParams.WRAP_CONTENT);
        setHeight(ViewGroup.LayoutParams.WRAP_CONTENT);
        setFocusable(true);
        setBackgroundDrawable(new ColorDrawable());
        setOutsideTouchable(true);
    }

    @Override
    public void onClick(View v) {
        if (v.getId() == R.id.item_ant_cloud) {
            gotoOnlinePage(ANT_FINANCIAL_CLOUD);
            dismiss();
        } else if (v.getId() == R.id.item_mpaas_doc) {
            gotoOnlinePage(MPAAS_DOC);
            dismiss();
        }
    }

    private void gotoOnlinePage(String url) {
        H5Service h5Service = LauncherApplicationAgent.getInstance().getMicroApplicationContext()
                .findServiceByInterface(H5Service.class.getName());
        Bundle bundle = new Bundle();
        bundle.putString(H5Param.LONG_URL, url);
        bundle.putBoolean(H5Param.LONG_SHOW_TITLEBAR, true);
        bundle.putBoolean(H5Param.LONG_SHOW_PROGRESS, true);
        bundle.putBoolean(H5Param.LONG_CAN_PULL_DOWN, true);
        bundle.putBoolean(H5Param.LONG_PULL_REFRESH, true);
        bundle.putString(H5Param.LONG_LANDSCAPE, "auto");
        h5Service.startPage(LauncherApplicationAgent.getInstance().getMicroApplicationContext().getTopApplication(),
                new H5Bundle(bundle));
    }
}
