package com.mpaas.demo.storage.testcase;

import com.mpaas.demo.storage.api.DemoOrmLiteSqliteOpenHelper;
import com.mpaas.demo.storage.api.User;
import com.mpaas.diagnose.CaseInfo;
import com.mpaas.diagnose.ICase;
import com.mpaas.framework.adapter.api.MPFramework;

import java.sql.SQLException;
import java.util.List;

import static com.mpaas.diagnose.CaseInfo.RESULT_CODE_FAIL;
import static com.mpaas.diagnose.CaseInfo.RESULT_CODE_SUCCESS;

public class DBStorageCase implements ICase {
    private static DBStorageCase sInstance;
    private CaseInfo mCaseInfo;
    private DemoOrmLiteSqliteOpenHelper mDbHelper;

    private DBStorageCase() {
    }

    public static DBStorageCase getInstance() {
        if (sInstance == null) {
            synchronized (DBStorageCase.class) {
                if (sInstance == null) {
                    sInstance = new DBStorageCase();
                }
            }
        }
        return sInstance;
    }

    @Override
    public CaseInfo getCaseInfo() {
        if (mCaseInfo == null) {
            mCaseInfo = new CaseInfo(
                    "Storage",
                    "Storage-000000",
                    "检测数据库增删改查功能",
                    "自动检测数据库增删改查功能",
                    false
            );
        }
        return mCaseInfo;
    }

    @Override
    public void run() {
        mDbHelper = new DemoOrmLiteSqliteOpenHelper(MPFramework.getApplicationContext());
        try {
            // 清空表
            User user = null;
            try {
                user = query();
            } catch (SQLException e) {
                e.printStackTrace();
                StorageDiagnoseController.service.reportCase(DBStorageCase.getInstance().getCaseInfo(), RESULT_CODE_FAIL, "DB查询失败");
                return;
            }
            if (user != null) {
                try {
                    mDbHelper.getDao(User.class).delete(user);
                } catch (SQLException e) {
                    e.printStackTrace();
                    StorageDiagnoseController.service.reportCase(DBStorageCase.getInstance().getCaseInfo(), RESULT_CODE_FAIL, "DB删除失败");
                    return;
                }
                try {
                    user = query();
                } catch (SQLException e) {
                    e.printStackTrace();
                    StorageDiagnoseController.service.reportCase(DBStorageCase.getInstance().getCaseInfo(), RESULT_CODE_FAIL, "DB查询失败");
                    return;
                }
                if (null != user) {
                    StorageDiagnoseController.service.reportCase(DBStorageCase.getInstance().getCaseInfo(), RESULT_CODE_FAIL, "DB删除失败");
                    return;
                }
            }
            // 插入新的 user
            user = new User();
            user.name = "DBStorageCase";
            user.color = 0XFFFFFF;
            user.timestamp = System.currentTimeMillis();
            try {
                mDbHelper.getDao(User.class).create(user);
            } catch (SQLException e) {
                StorageDiagnoseController.service.reportCase(DBStorageCase.getInstance().getCaseInfo(), RESULT_CODE_FAIL, "DB插入失败");
                return;
            }
            // 验证插入
            try {
                user = query();
            } catch (Exception e) {
                e.printStackTrace();
                StorageDiagnoseController.service.reportCase(DBStorageCase.getInstance().getCaseInfo(), RESULT_CODE_FAIL, "DB查询失败");
                return;
            }
            if (null == user) {
                StorageDiagnoseController.service.reportCase(DBStorageCase.getInstance().getCaseInfo(), RESULT_CODE_FAIL, "DB插入失败");
                return;
            }
            // 修改 user
            long time = System.currentTimeMillis() + 1000;
            user.timestamp = time;
            try {
                mDbHelper.getDao(User.class).update(user);
            } catch (SQLException e) {
                e.printStackTrace();
                StorageDiagnoseController.service.reportCase(DBStorageCase.getInstance().getCaseInfo(), RESULT_CODE_FAIL, "DB修改失败");
                return;
            }
            // 验证修改
            try {
                user = query();
            } catch (Exception e) {
                e.printStackTrace();
                StorageDiagnoseController.service.reportCase(DBStorageCase.getInstance().getCaseInfo(), RESULT_CODE_FAIL, "DB查询失败");
                return;
            }
            if (null == user) {
                StorageDiagnoseController.service.reportCase(DBStorageCase.getInstance().getCaseInfo(), RESULT_CODE_FAIL, "DB查询失败");
                return;
            }
            if (time != user.timestamp) {
                StorageDiagnoseController.service.reportCase(DBStorageCase.getInstance().getCaseInfo(), RESULT_CODE_FAIL, "DB修改失败");
                return;
            }
            // 删除 user
            try {
                mDbHelper.getDao(User.class).delete(user);
            } catch (SQLException e) {
                e.printStackTrace();
                StorageDiagnoseController.service.reportCase(DBStorageCase.getInstance().getCaseInfo(), RESULT_CODE_FAIL, "DB删除失败");
                return;
            }
            try {
                user = query();
            } catch (Exception e) {
                e.printStackTrace();
                StorageDiagnoseController.service.reportCase(DBStorageCase.getInstance().getCaseInfo(), RESULT_CODE_FAIL, "DB查询失败");
                return;
            }
            if (null != user) {
                StorageDiagnoseController.service.reportCase(DBStorageCase.getInstance().getCaseInfo(), RESULT_CODE_FAIL, "DB删除失败");
                return;
            }
            StorageDiagnoseController.service.reportCase(DBStorageCase.getInstance().getCaseInfo(), RESULT_CODE_SUCCESS, "");
        }catch (Exception e){
        }finally {
            mDbHelper.close();
        }
    }

    private User query() throws SQLException {
        List<User> users = null;
        users = mDbHelper.getDao(User.class).queryBuilder().where().eq("name", "DBStorageCase").query();
        if (null != users && users.size() > 0) {
            return users.get(0);
        }
        return null;
    }
}