package com.mpaas.demo.storage.testcase;

import com.alipay.android.phone.mobilesdk.storage.file.ZSecurityFileInputStream;
import com.alipay.android.phone.mobilesdk.storage.file.ZSecurityFileOutputStream;
import com.mpaas.diagnose.CaseInfo;
import com.mpaas.diagnose.ICase;
import com.mpaas.framework.adapter.api.MPFramework;

import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import java.io.InputStreamReader;
import java.io.OutputStreamWriter;
import java.io.StringReader;
import java.io.StringWriter;

import static com.mpaas.demo.storage.testcase.StorageDiagnoseController.GROUP_ID;
import static com.mpaas.diagnose.CaseInfo.RESULT_CODE_FAIL;
import static com.mpaas.diagnose.CaseInfo.RESULT_CODE_SUCCESS;

public class FileStorageCase implements ICase {
    public static final String TAG = "FileStorageCase";
    private static final int DEFAULT_BUFFER_SIZE = 1024;
    private static FileStorageCase sInstance;
    private CaseInfo mCaseInfo;

    private String mExternalFilePath;

    private FileStorageCase() {
    }

    public static FileStorageCase getInstance() {
        if (sInstance == null) {
            synchronized (FileStorageCase.class) {
                if (sInstance == null) {
                    sInstance = new FileStorageCase();
                }
            }
        }
        return sInstance;
    }

    @Override
    public CaseInfo getCaseInfo() {
        if (mCaseInfo == null) {
            mCaseInfo = new CaseInfo(
                    "Storage",
                    "Storage-000002",
                    "检测文件加解密功能",
                    "自动检测文件加解密功能",
                    false
            );
        }
        return mCaseInfo;
    }

    @Override
    public void run() {
        mExternalFilePath = MPFramework.getApplicationContext().getExternalFilesDir(GROUP_ID).getAbsolutePath();
        if(!mExternalFilePath.endsWith("/")){
            mExternalFilePath = mExternalFilePath+"/";
        }
        try {
            File file;
            file = new File(mExternalFilePath +"/"+ TAG);
            if (file.exists()) {
                file.delete();
            }
            // 插入
            file = new File(mExternalFilePath + TAG);
            string2File(TAG, file);
            if (!file.exists()) {
                StorageDiagnoseController.service.reportCase(FileStorageCase.getInstance().getCaseInfo(), RESULT_CODE_FAIL, "File插入、加密失败");
                return;
            }
            String unEncrypt = file2String(file,false);
            if(TAG.equals(unEncrypt)){
                StorageDiagnoseController.service.reportCase(FileStorageCase.getInstance().getCaseInfo(), RESULT_CODE_FAIL, "File加密失败");
                return;
            }
            String encrypt = file2String(file,true);
            if(!TAG.equals(encrypt)){
                StorageDiagnoseController.service.reportCase(FileStorageCase.getInstance().getCaseInfo(), RESULT_CODE_FAIL, "File解密失败");
                return;
            }
            if (file.exists()) {
                file.delete();
            }
            StorageDiagnoseController.service.reportCase(FileStorageCase.getInstance().getCaseInfo(), RESULT_CODE_SUCCESS, "");
        } catch (Exception e) {
        } finally {
        }
    }

    /**
     * 文件转文本
     *
     * @param file 文件
     * @return 文本
     */
    public String file2String(File file, boolean isSecurity) {
        InputStreamReader reader = null;
        StringWriter writer = new StringWriter();
        try {
            if (isSecurity) {
                reader = new InputStreamReader(new ZSecurityFileInputStream(file, MPFramework.getApplicationContext()));
            } else {
                reader = new InputStreamReader(new FileInputStream(file));
            }
            //将输入流写入输出流
            char[] buffer = new char[DEFAULT_BUFFER_SIZE];
            int n = 0;
            while (-1 != (n = reader.read(buffer))) {
                writer.write(buffer, 0, n);
            }
        } catch (Exception e) {
            e.printStackTrace();
            return null;
        } finally {
            if (reader != null)
                try {
                    reader.close();
                } catch (IOException e) {
                    e.printStackTrace();
                }
        }
        //返回转换结果
        if (writer != null) {
            return writer.toString();
        } else {
            return null;
        }
    }

    /**
     * 文本转文件
     *
     * @param res  文本
     * @param file 文件
     * @return true表示成功，反之失败
     */
    public boolean string2File(String res, File file) {
        boolean flag = true;
        BufferedReader bufferedReader = null;
        BufferedWriter bufferedWriter;
        try {
            bufferedReader = new BufferedReader(new StringReader(res));
            bufferedWriter = new BufferedWriter(new OutputStreamWriter(new ZSecurityFileOutputStream(file, MPFramework.getApplicationContext())));
            //字符缓冲区
            char buf[] = new char[DEFAULT_BUFFER_SIZE];
            int len;
            while ((len = bufferedReader.read(buf)) != -1) {
                bufferedWriter.write(buf, 0, len);
            }
            bufferedWriter.flush();
            bufferedReader.close();
            bufferedWriter.close();
        } catch (Exception e) {
            e.printStackTrace();
            flag = false;
            return flag;
        } finally {
            if (bufferedReader != null) {
                try {
                    bufferedReader.close();
                } catch (IOException e) {
                    e.printStackTrace();
                }
            }
        }
        return flag;
    }
}