package com.mpaas.demo.storage.testcase;

import android.text.TextUtils;

import com.alipay.android.phone.mobilesdk.storage.sp.APSharedPreferences;
import com.alipay.android.phone.mobilesdk.storage.sp.SharedPreferencesManager;
import com.mpaas.diagnose.CaseInfo;
import com.mpaas.diagnose.ICase;
import com.mpaas.framework.adapter.api.MPFramework;

import java.sql.SQLException;

import static com.mpaas.demo.storage.testcase.StorageDiagnoseController.GROUP_ID;
import static com.mpaas.diagnose.CaseInfo.RESULT_CODE_FAIL;
import static com.mpaas.diagnose.CaseInfo.RESULT_CODE_SUCCESS;

public class KVStorageCase implements ICase {
    public static final String TAG = "KVStorageCase";
    private static KVStorageCase sInstance;
    private CaseInfo mCaseInfo;

    private APSharedPreferences mAPSharedPreferences;

    private KVStorageCase() {
    }

    public static KVStorageCase getInstance() {
        if (sInstance == null) {
            synchronized (KVStorageCase.class) {
                if (sInstance == null) {
                    sInstance = new KVStorageCase();
                }
            }
        }
        return sInstance;
    }

    @Override
    public CaseInfo getCaseInfo() {
        if (mCaseInfo == null) {
            mCaseInfo = new CaseInfo(
                    "Storage",
                    "Storage-000001",
                    "检测KV增删改查功能",
                    "自动检测KV增删改查功能",
                    false
            );
        }
        return mCaseInfo;
    }

    @Override
    public void run() {
        mAPSharedPreferences = SharedPreferencesManager.getInstance(MPFramework.getApplicationContext(), GROUP_ID);
        try {
            String value = "";
            // 清空
            value = mAPSharedPreferences.getString(TAG, "");
            if (!TextUtils.isEmpty(value)) {
                mAPSharedPreferences.remove(TAG);
                mAPSharedPreferences.commit();
                value = mAPSharedPreferences.getString(TAG, "");
                if (!TextUtils.isEmpty(value)) {
                    StorageDiagnoseController.service.reportCase(KVStorageCase.getInstance().getCaseInfo(), RESULT_CODE_FAIL, "KV删除失败");
                    return;
                }
            }
            // 插入
            mAPSharedPreferences.putString(TAG, TAG);
            mAPSharedPreferences.commit();
            // 验证插入
            value = mAPSharedPreferences.getString(TAG, "");
            if (TextUtils.isEmpty(value)) {
                StorageDiagnoseController.service.reportCase(KVStorageCase.getInstance().getCaseInfo(), RESULT_CODE_FAIL, "KV插入失败");
                return;
            }
            // 修改
            mAPSharedPreferences.putString(TAG, "update");
            mAPSharedPreferences.commit();
            // 验证修改
            value = mAPSharedPreferences.getString(TAG, "");
            if (!"update".equals(value)) {
                StorageDiagnoseController.service.reportCase(KVStorageCase.getInstance().getCaseInfo(), RESULT_CODE_FAIL, "KV修改失败");
                return;
            }
            // 删除
            mAPSharedPreferences.remove(TAG);
            mAPSharedPreferences.commit();
            value = mAPSharedPreferences.getString(TAG, "");
            if (!TextUtils.isEmpty(value)) {
                StorageDiagnoseController.service.reportCase(KVStorageCase.getInstance().getCaseInfo(), RESULT_CODE_FAIL, "KV删除失败");
                return;
            }
            StorageDiagnoseController.service.reportCase(KVStorageCase.getInstance().getCaseInfo(), RESULT_CODE_SUCCESS, "");
        } catch (Exception e) {
        } finally {
        }
    }
}