package com.mpaas.demo.sync.testcase;

import android.text.TextUtils;
import android.util.Base64;

import com.alipay.mobile.common.logging.api.LoggerFactory;
import com.alipay.mobile.rome.longlinkservice.ISyncCallback;
import com.alipay.mobile.rome.longlinkservice.syncmodel.SyncMessage;
import com.mpaas.diagnose.CaseInfo;
import com.mpaas.diagnose.ICase;
import com.mpaas.mas.adapter.api.MPLogger;
import com.mpaas.mss.adapter.api.MPSync;

import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;

import static com.mpaas.diagnose.CaseInfo.RESULT_CODE_FAIL;
import static com.mpaas.diagnose.CaseInfo.RESULT_CODE_SUCCESS;

/**
 * Created by larry.cl.
 */
public class OneUserSyncCase implements ICase {

    private static OneUserSyncCase sInstance;
    private CaseInfo mCaseInfo;
    private ISyncCallback mSyncCallback = new ISyncCallback() {
        @Override
        public void onReceiveMessage(SyncMessage syncMessage) {
            //最终的数据是以JSONArray放在 msgData 字段中
            LoggerFactory.getTraceLogger().debug(SyncDiagnoseController.TAG, "SyncCallback onReceiveMessage:" + syncMessage.msgData + "/" + syncMessage.userId + "/" + syncMessage.biz);
            if (syncMessage != null && !TextUtils.isEmpty(syncMessage.msgData)) {
                try {
                    JSONArray jsonArray = new JSONArray(syncMessage.msgData);
                    int count = jsonArray.length();
                    for (int index = 0; index < count; index++) {
                        JSONObject jsonObject = (JSONObject) jsonArray.get(index);
                        //最终需要的数据就在下面字段finalData中。
                        String finalData = jsonObject.optString("pl");
                        //对于isB标志,需要base64解码
                        if ("1".equals(jsonObject.optString("isB"))) {
                            finalData = new String(Base64.decode(finalData, Base64.DEFAULT), "UTF-8");
                        }
                        if ("000".equals(finalData)) {
                            SyncDiagnoseController.service.reportCase(OneUserSyncCase.getInstance().getCaseInfo(), RESULT_CODE_SUCCESS, "用户成功同步消息");
                        }
                    }
                    MPSync.reportMsgReceived(syncMessage);
                } catch (JSONException e) {
                    SyncDiagnoseController.service.reportCase(OneUserSyncCase.getInstance().getCaseInfo(), RESULT_CODE_FAIL, "用户同步消息异常");
                    LoggerFactory.getTraceLogger().error(SyncDiagnoseController.TAG, "SyncCallback onReceiveMessage JSONException" + syncMessage.msgData + "/" + syncMessage.userId + "/" + syncMessage.biz);
                } catch (Exception e) {
                    SyncDiagnoseController.service.reportCase(OneUserSyncCase.getInstance().getCaseInfo(), RESULT_CODE_FAIL, "用户同步消息异常");
                    LoggerFactory.getTraceLogger().error(SyncDiagnoseController.TAG, "SyncCallback onReceiveMessage : " + e);
                }
            }
        }
    };

    private OneUserSyncCase() {

    }

    public static OneUserSyncCase getInstance() {
        if (sInstance == null) {
            synchronized (OneUserSyncCase.class) {
                if (sInstance == null) {
                    sInstance = new OneUserSyncCase();
                }
            }
        }
        return sInstance;
    }

    @Override
    public CaseInfo getCaseInfo() {
        if (mCaseInfo == null) {
            mCaseInfo = new CaseInfo(
                    "Sync",
                    "Sync-000002",
                    "检测Sync指定用户同步功能",
                    "手动检测Sync指定用户同步功能",
                    true
            );
        }
        return mCaseInfo;
    }

    @Override
    public void run() {
        MPSync.registerBiz("oneUserSync", mSyncCallback);
        String userId = MPLogger.getUserId();
        LoggerFactory.getTraceLogger().error(SyncDiagnoseController.TAG, "sync userId : " + userId);
        //LongLinkSyncService.getInstance().updateUserInfo(userId, "test");
        MPSync.updateUserInfo("test");
    }


}
