package com.mpaas.demo.upgrade;

import android.content.pm.PackageManager;
import android.os.Bundle;
import android.view.View;

import com.alipay.mobile.android.security.upgrade.util.UpdateUtils;
import com.alipay.mobile.antui.basic.AUButton;
import com.alipay.mobile.antui.basic.AUTextView;
import com.alipay.mobile.antui.basic.AUTitleBar;
import com.alipay.mobile.antui.dialog.AUNoticeDialog;
import com.alipay.mobile.antui.dialog.AUProgressDialog;
import com.alipay.mobile.antui.load.AULineProgressBar;
import com.alipay.mobile.framework.app.ui.BaseActivity;
import com.alipay.mobileappcommon.biz.rpc.client.upgrade.model.ClientUpgradeRes;
import com.mpaas.demo.sharedres.MenuPopupWindow;
import com.mpaas.mpaasadapter.api.upgrade.MPUpgrade;

import java.util.ArrayList;
import java.util.List;

public class UpgradeActivity extends BaseActivity {

    private AUTextView mCurVersionTv;
    private AUButton mDefaultIntervalUpgradeBtn;
    private AUButton mCustomIntervalUpgradeBtn;

    private AUProgressDialog mCheckUpgradeProgressDialog;
    private AUNoticeDialog mDownloadDialog;
    private AUNoticeDialog mDownloadProgressDialog;
    private AULineProgressBar mDownloadProgressBar;
    private AUNoticeDialog mInstallDialog;
    private AUTitleBar mTitle;

    private MPUpgrade mMPUpgrade = new MPUpgrade();

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_upgrade);
        // 设置升级服务的回调函数
        mMPUpgrade.setUpgradeCallback(new UpgradeCallBack(this));
        findView();
        initView();
    }

    private void findView() {
        mTitle = (AUTitleBar) findViewById(R.id.title_atb);
        mCurVersionTv = (AUTextView) findViewById(R.id.upgrade_cur_version_tv);
        mDefaultIntervalUpgradeBtn = (AUButton) findViewById(R.id.upgrade_default_interval_btn);
        mCustomIntervalUpgradeBtn = (AUButton) findViewById(R.id.upgrade_custom_interval_btn);
    }

    private void initView() {
        mTitle.setTitleText(getString(R.string.upgrade_release), (int)getResources().getDimension(com.mpaas.demo.sharedres.R.dimen.text_size)
                , getResources().getColor(com.mpaas.demo.sharedres.R.color.title_color));
        mTitle.getRightButtonIconView().setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                MenuPopupWindow popupWindow = new MenuPopupWindow(UpgradeActivity.this);
                popupWindow.showAsDropDown(mTitle.getRightButtonIconView(), 0, 0);
            }
        });
        mCheckUpgradeProgressDialog = new AUProgressDialog(this);
        mCheckUpgradeProgressDialog.setMessage(getString(R.string.checking_upgrade));
        mCheckUpgradeProgressDialog.setCanceledOnTouchOutside(false);

        mDownloadProgressBar = new AULineProgressBar(this);
        List<View> views = new ArrayList<>();
        views.add(mDownloadProgressBar);
        mDownloadProgressDialog = new AUNoticeDialog(this, "", getString(R.string.downloading), "", "", false, views);
        mDownloadProgressDialog.setCancelable(false);

        try {
            mCurVersionTv.setText(getString(R.string.cur_ver_is) + getPackageManager().getPackageInfo(getPackageName(), 0).versionName);
        } catch (PackageManager.NameNotFoundException e) {
            e.printStackTrace();
        }
        mDefaultIntervalUpgradeBtn.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View view) {
                // 更新提示间隔时间设置成-1时，采用默认的3天作为更新提示间隔时间
                // 开发者可以再此处设置任意更新提示间隔时间，该时间只对单次升级模式生效
                mMPUpgrade.setIntervalTime(-1);
                mMPUpgrade.checkNewVersion(UpgradeActivity.this);
            }
        });
        mCustomIntervalUpgradeBtn.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View view) {
                // 更新提示间隔时间设置成60*1000时（1分钟），表示两次升级弹框超过一分钟才会弹出
                // 开发者可以再此处设置任意更新提示间隔时间，该时间只对单次升级模式生效
                mMPUpgrade.setIntervalTime(60 * 1000);
                mMPUpgrade.checkNewVersion(UpgradeActivity.this);
            }
        });
    }

    /**
     * 显示版本检测的ProgressDialog
     */
    public void showCheckUpgradeProgressDialog() {
        mCheckUpgradeProgressDialog.show();
    }

    /**
     * 取消版本检测的ProgressDialog
     */
    public void cancelCheckUpgradeProgressDialog() {
        mCheckUpgradeProgressDialog.cancel();
    }

    /**
     * 显示下载dialog
     *
     * @param clientUpgradeRes 更新结果
     */
    public void showDownloadDialog(final ClientUpgradeRes clientUpgradeRes) {
        String title = getString(R.string.upgrade);
        // 默认不是强制升级
        boolean isForce = false;
        // 根据不同的升级策略，显示不同的dialog标题。
        // 强制升级策略下无法取消dialog。
        switch (clientUpgradeRes.resultStatus) {
            // 状态值为202，单次提醒升级
            case 202:
                title = getString(R.string.single_upgrade);
                break;
            // 状态值为204，多次提醒升级
            case 204:
                title = getString(R.string.multi_upgrade);
                break;
            // 状态值为203或206，强制升级
            case 203:
            case 206:
                title = getString(R.string.force_upgrade);
                isForce = true;
                break;
            default:
                title = getString(R.string.unknown_upgrade_state) + clientUpgradeRes.resultStatus;
                break;
        }
        mDownloadDialog = new AUNoticeDialog(this,
                title,
                clientUpgradeRes.guideMemo,
                // 如果是强制升级，则不显示取消按钮
                getString(R.string.upgrade), isForce ? "" : getString(R.string.cancel),
                !isForce);
        // 如果是强制升级，则不可取消dialog
        mDownloadDialog.setCancelable(!isForce);
        // 设置升级点击事件
        mDownloadDialog.setPositiveListener(new AUNoticeDialog.OnClickPositiveListener() {
            @Override
            public void onClick() {
                // 进行更新
                mMPUpgrade.update(clientUpgradeRes, new DownloadCallback(UpgradeActivity.this));
            }
        });
        mDownloadDialog.show();
    }

    /**
     * 显示下载ProgressDialog
     */
    public void showDownloadProgressDialog() {
        mDownloadProgressBar.setProgress(0);
        mDownloadProgressDialog.show();
    }

    /**
     * 更新下载ProgressDialog的百分比
     *
     * @param percent 百分比
     */
    public void updateDownloadProgressDialog(int percent) {
        mDownloadProgressBar.setProgress(percent);
    }

    /**
     * 取消下载ProgressDialog
     */
    public void cancelDownloadProgressDialog() {
        mDownloadProgressBar.setProgress(0);
        mDownloadProgressDialog.cancel();
    }

    /**
     * 显示安装dialog
     *
     * @param apkPath apk路径
     * @param isForce 是否强制安装
     */
    public void showInstallDialog(final String apkPath, boolean isForce) {
        mInstallDialog = new AUNoticeDialog(this,
                getString(R.string.install_new),
                (getString(R.string.apk_path) + apkPath),
                getString(R.string.install),
                // 强制安装不显示取消按钮
                isForce ? "" : getString(R.string.cancel),
                !isForce);
        // 强制安装无法取消
        mInstallDialog.setCancelable(!isForce);
        mInstallDialog.setPositiveListener(new AUNoticeDialog.OnClickPositiveListener() {
            @Override
            public void onClick() {
                // 安装
                UpdateUtils.installApk(apkPath);
            }
        });
        mInstallDialog.show();
    }
}
